'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var styled = require('reakit/styled');
var styled__default = _interopDefault(styled);
var styledTools = require('styled-tools');
require('styled-selector');
require('../styled/selector.js');
require('lodash/get');
require('../styled/space.js');
var index$2 = require('../styled/index.js');
var Box = _interopDefault(require('reakit/Box'));
require('reakit/Block');
require('reakit/Inline');
require('reakit/InlineBlock');
require('reakit/Flex');
require('reakit/InlineFlex');
require('reakit/Grid');

var marginAutoOffsets = {
  left: styled.css(["margin-left:auto;"]),
  both: styled.css(["margin-left:auto;margin-right:auto;"]),
  right: styled.css(["margin-right:auto;"])
};
var getWidth = function getWidth(spread) {
  return spread / 12 * 100 + "%";
};
var getSpreadProperties = function getSpreadProperties(props) {
  var minBreakpoint = props.minBreakpoint,
      spread = props.spread,
      spreadMobile = props.spreadMobile,
      spreadTablet = props.spreadTablet,
      spreadDesktop = props.spreadDesktop,
      spreadWidescreen = props.spreadWidescreen,
      spreadFullHD = props.spreadFullHD;

  if (!minBreakpoint && !spread && !spreadMobile && !spreadTablet && !spreadDesktop && !spreadWidescreen && !spreadFullHD) {
    return styled.css(["@media (max-width:", "px){flex:none;width:100%;}"], styledTools.theme('fannypack.layout.tabletBreakpoint'));
  }

  var getProperties = function getProperties(_ref) {
    var breakpoint = _ref.breakpoint,
        spread = _ref.spread;
    var properties = styled.css(["flex:none;width:", ";"], getWidth(spread));
    if (!spread) return null;

    if (breakpoint) {
      return styled.css(["@media (max-width:", "px){", ";}"], styledTools.theme("fannypack.layout." + breakpoint), properties);
    }

    return properties;
  };

  return styled.css(["", ";", ";", ";", ";", ";", ";", ";", ";"], getProperties({
    spread: spread
  }), getProperties({
    spread: spreadFullHD,
    breakpoint: 'fullHDBreakpoint'
  }), getProperties({
    spread: spreadWidescreen,
    breakpoint: 'widescreenBreakpoint'
  }), getProperties({
    spread: spreadDesktop,
    breakpoint: 'desktopBreakpoint'
  }), minBreakpoint !== 'tablet' && minBreakpoint !== 'mobile' && !spreadTablet && !spreadMobile && styled.css(["@media (max-width:", "px){width:100%;}"], styledTools.theme('fannypack.layout.tabletBreakpoint')), getProperties({
    spread: spreadTablet,
    breakpoint: 'tabletBreakpoint'
  }), minBreakpoint !== 'mobile' && !spreadMobile && styled.css(["@media (max-width:", "px){width:100%;}"], styledTools.theme('fannypack.layout.mobileBreakpoint')), getProperties({
    spread: spreadMobile,
    breakpoint: 'mobileBreakpoint'
  }));
};
var getSpreadOffsetProperties = function getSpreadOffsetProperties(props) {
  var spreadOffset = props.spreadOffset,
      spreadMobileOffset = props.spreadMobileOffset,
      spreadTabletOffset = props.spreadTabletOffset,
      spreadDesktopOffset = props.spreadDesktopOffset,
      spreadWidescreenOffset = props.spreadWidescreenOffset,
      spreadFullHDOffset = props.spreadFullHDOffset;

  if (!spreadOffset && !spreadMobileOffset && !spreadTabletOffset && !spreadDesktopOffset && !spreadWidescreenOffset && !spreadFullHDOffset) {
    return null;
  }

  var getProperties = function getProperties(_ref2) {
    var breakpoint = _ref2.breakpoint,
        spreadOffset = _ref2.spreadOffset;
    var properties = styled.css(["margin-left:", ";"], getWidth(spreadOffset));
    if (!spreadOffset) return null;

    if (breakpoint) {
      return styled.css(["@media (max-width:", "px){", ";}"], styledTools.theme("fannypack.layout." + breakpoint), properties);
    }

    return properties;
  };

  if (typeof spreadOffset === 'number') {
    return styled.css(["", ";", ";", ";", ";", ";", ";", ";", ";"], getProperties({
      spreadOffset: spreadOffset
    }), getProperties({
      spreadOffset: spreadFullHDOffset,
      breakpoint: 'fullHDBreakpoint'
    }), getProperties({
      spreadOffset: spreadWidescreenOffset,
      breakpoint: 'widescreenBreakpoint'
    }), getProperties({
      spreadOffset: spreadDesktopOffset,
      breakpoint: 'desktopBreakpoint'
    }), !spreadTabletOffset && !spreadMobileOffset && styled.css(["@media (max-width:", "px){margin-left:0;}"], styledTools.theme('fannypack.layout.tabletBreakpoint')), getProperties({
      spreadOffset: spreadTabletOffset,
      breakpoint: 'tabletBreakpoint'
    }), !spreadMobileOffset && styled.css(["@media (max-width:", "px){margin-left:0;}"], styledTools.theme('fannypack.layout.mobileBreakpoint')), getProperties({
      spreadOffset: spreadMobileOffset,
      breakpoint: 'mobileBreakpoint'
    }));
  }

  return marginAutoOffsets[spreadOffset];
};
var Column = index$2.default(Box).withConfig({
  displayName: "styled__Column",
  componentId: "sc-1lmgd0f-0"
})(["flex:1;max-width:100%;", ";&{", ";}&{", ";}&{", ";}"], function (props) {
  return !props.isGapless ? styled.css(["padding:", "rem;"], styledTools.theme('fannypack.layout.gapFactor')) : null;
}, getSpreadProperties, getSpreadOffsetProperties, styledTools.theme('fannypack.Column.base'));

exports.Column = Column;
exports.default = Column;
exports.getSpreadOffsetProperties = getSpreadOffsetProperties;
exports.getSpreadProperties = getSpreadProperties;
exports.getWidth = getWidth;
exports.marginAutoOffsets = marginAutoOffsets;
