'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var uniqueId = require('../uniqueId.js');
var PropTypes = require('prop-types');
require('../types/props.js');
require('reakit/styled');
require('styled-tools');
require('styled-selector');
require('../styled/selector.js');
require('lodash/get');
require('../styled/space.js');
require('../styled/index.js');
var __chunk_1 = require('../chunk-c300b528.js');
require('polished');
require('../default/palette.js');
require('reakit/Button');
require('airbnb-prop-types');
require('../parseIcons.js');
var Box = _interopDefault(require('reakit/Box'));
require('reakit/Block');
require('reakit/Inline');
require('reakit/InlineBlock');
require('reakit/Flex');
require('reakit/InlineFlex');
require('reakit/Grid');
require('../Icon/styled.js');
require('../chunk-bf58d135.js');
require('../Set/styled.js');
require('../Set/index.js');
require('../Button/styled.js');
require('../Spinner/styled.js');
require('../Spinner/index.js');
var __chunk_3 = require('../chunk-7592c834.js');
var _omit = _interopDefault(require('lodash/omit'));
var ActionButtons = require('../Button/ActionButtons.js');
require('../Button/index.js');
require('classnames');
require('reakit/Heading');
require('../Heading/styled.js');
require('../Heading/index.js');
require('../Pane/styled.js');
require('../chunk-66ca61c2.js');
require('../Pane/index.js');
require('../Icon/index.js');
require('../VisuallyHidden.js');
require('./styled.js');
var DialogDialog = require('./DialogDialog.js');
var DialogContent = require('./DialogContent.js');
var DialogHeader = require('./DialogHeader.js');
var DialogFooter = require('./DialogFooter.js');
var DialogTitle = require('./DialogTitle.js');
var DialogClose = require('./DialogClose.js');
var DialogIcon = require('./DialogIcon.js');

var Dialog = function Dialog(_ref) {
  var _a11yDescriptionId = _ref.a11yDescriptionId,
      _a11yTitleId = _ref.a11yTitleId,
      actionButtonsProps = _ref.actionButtonsProps,
      children = _ref.children,
      closeButtonProps = _ref.closeButtonProps,
      footer = _ref.footer,
      hasScroll = _ref.hasScroll,
      onClickClose = _ref.onClickClose,
      showActionButtons = _ref.showActionButtons,
      showCloseButton = _ref.showCloseButton,
      title = _ref.title,
      type = _ref.type,
      props = __chunk_1._objectWithoutPropertiesLoose(_ref, ["a11yDescriptionId", "a11yTitleId", "actionButtonsProps", "children", "closeButtonProps", "footer", "hasScroll", "onClickClose", "showActionButtons", "showCloseButton", "title", "type"]);

  var titleId = uniqueId.useUniqueId('Dialog');
  var descriptionId = uniqueId.useUniqueId('Dialog');
  var a11yDescriptionId = _a11yDescriptionId || descriptionId;
  var a11yTitleId = _a11yTitleId || titleId;
  return React.createElement(DialogDialog.default, __chunk_1._extends({
    a11yDescriptionId: a11yDescriptionId,
    a11yTitleId: a11yTitleId
  }, props), title && React.createElement(DialogHeader.default, null, typeof title === 'string' ? React.createElement(DialogTitle.default, {
    id: a11yTitleId
  }, type && React.createElement(DialogIcon.default, {
    a11yHidden: true,
    color: type,
    icon: type
  }), title) : title, showCloseButton && React.createElement(DialogClose.default, __chunk_1._extends({
    onClick: onClickClose
  }, closeButtonProps))), React.createElement(DialogContent.default, {
    id: a11yDescriptionId,
    hasScroll: hasScroll
  }, children), (footer || showActionButtons) && React.createElement(DialogFooter.default, {
    justifyContent: footer ? 'space-between' : 'flex-end'
  }, footer && React.createElement(Box, null, footer), showActionButtons && React.createElement(Box, null, React.createElement(ActionButtons.default, actionButtonsProps))));
};
Dialog.Dialog = DialogDialog.default;
Dialog.Header = DialogHeader.default;
Dialog.Content = DialogContent.default;
Dialog.Footer = DialogFooter.default;
Dialog.Title = DialogTitle.default;
Dialog.Close = DialogClose.default;
Dialog.Icon = DialogIcon.default;
var dialogPropTypes = __chunk_1._objectSpread({
  actionButtonsProps: PropTypes.shape(ActionButtons.actionButtonsPropTypes),
  a11yDescriptionId: PropTypes.string,
  a11yTitleId: PropTypes.string,
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  closeButtonProps: PropTypes.shape(_omit(__chunk_3.buttonPropTypes, 'children')),
  footer: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  hasScroll: PropTypes.bool,
  onClickClose: PropTypes.func,
  showActionButtons: PropTypes.bool,
  showCloseButton: PropTypes.bool,
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  type: PropTypes.string
}, DialogDialog.dialogDialogPropTypes);
Dialog.propTypes = dialogPropTypes;
var dialogDefaultProps = __chunk_1._objectSpread({}, DialogDialog.dialogDialogDefaultProps, {
  actionButtonsProps: {},
  a11yDescriptionId: undefined,
  a11yTitleId: undefined,
  className: undefined,
  closeButtonProps: {},
  footer: undefined,
  hasScroll: false,
  onClickClose: undefined,
  showActionButtons: false,
  showCloseButton: false,
  title: undefined,
  type: undefined
});
Dialog.defaultProps = dialogDefaultProps; // @ts-ignore

var C = Dialog;

exports.DialogDialog = DialogDialog.default;
exports.dialogDialogDefaultProps = DialogDialog.dialogDialogDefaultProps;
exports.dialogDialogPropTypes = DialogDialog.dialogDialogPropTypes;
exports.DialogContent = DialogContent.default;
exports.dialogContentDefaultProps = DialogContent.dialogContentDefaultProps;
exports.dialogContentPropTypes = DialogContent.dialogContentPropTypes;
exports.DialogHeader = DialogHeader.default;
exports.dialogHeaderDefaultProps = DialogHeader.dialogHeaderDefaultProps;
exports.dialogHeaderPropTypes = DialogHeader.dialogHeaderPropTypes;
exports.DialogFooter = DialogFooter.default;
exports.dialogFooterDefaultProps = DialogFooter.dialogFooterDefaultProps;
exports.dialogFooterPropTypes = DialogFooter.dialogFooterPropTypes;
exports.DialogTitle = DialogTitle.default;
exports.dialogTitleDefaultProps = DialogTitle.dialogTitleDefaultProps;
exports.dialogTitlePropTypes = DialogTitle.dialogTitlePropTypes;
exports.DialogClose = DialogClose.default;
exports.dialogCloseDefaultProps = DialogClose.dialogCloseDefaultProps;
exports.dialogClosePropTypes = DialogClose.dialogClosePropTypes;
exports.DialogIcon = DialogIcon.default;
exports.dialogIconDefaultProps = DialogIcon.dialogIconDefaultProps;
exports.dialogIconPropTypes = DialogIcon.dialogIconPropTypes;
exports.Dialog = C;
exports.default = C;
exports.dialogDefaultProps = dialogDefaultProps;
exports.dialogPropTypes = dialogPropTypes;
