'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = require('prop-types');
require('../types/props.js');
require('reakit/styled');
require('styled-tools');
require('styled-selector');
require('../styled/selector.js');
require('lodash/get');
require('../styled/space.js');
require('../styled/index.js');
var __chunk_1 = require('../chunk-c300b528.js');
require('polished');
require('../default/palette.js');
require('reakit/Button');
require('airbnb-prop-types');
require('../parseIcons.js');
require('reakit/Box');
require('reakit/Block');
require('reakit/Inline');
require('reakit/InlineBlock');
require('reakit/Flex');
require('reakit/InlineFlex');
require('reakit/Grid');
require('../Icon/styled.js');
require('../chunk-bf58d135.js');
require('../Set/styled.js');
require('../Set/index.js');
require('../Button/styled.js');
require('../Spinner/styled.js');
require('../Spinner/index.js');
require('../chunk-7592c834.js');
require('lodash/omit');
require('../Button/ActionButtons.js');
require('../Button/index.js');
require('../Pane/styled.js');
require('../chunk-66ca61c2.js');
require('../Pane/index.js');
require('../Icon/index.js');
require('../VisuallyHidden.js');
require('reakit/Navigation');
require('../Navigation/styled.js');
var __chunk_5 = require('../chunk-83d5c735.js');
require('../Navigation/index.js');
require('../chunk-f686853d.js');
require('reakit/Popover');
require('../Popover/PopoverContainer.js');
require('../Popover/styled.js');
require('../Popover/PopoverHide.js');
require('../Popover/PopoverClose.js');
require('focus-trap');
require('../chunk-c50ee195.js');
require('../Popover/PopoverPopover.js');
require('../Popover/PopoverShow.js');
require('../Popover/PopoverToggle.js');
require('../chunk-ec80954a.js');
require('reakit/Divider');
require('../Divider/styled.js');
require('../Divider/index.js');
require('../Popover/index.js');
var styled$4 = require('./styled.js');
var MenuContext = require('./MenuContext.js');
var MenuTrigger = require('./MenuTrigger.js');
var MenuButton = require('./MenuButton.js');
var MenuDivider = require('./MenuDivider.js');
var MenuGroup = require('./MenuGroup.js');
var MenuItem = require('./MenuItem.js');
var MenuPopover = require('./MenuPopover.js');

var KEYS = {
  UP: 38,
  DOWN: 40,
  LEFT: 37,
  RIGHT: 39,
  HOME: 36,
  END: 35,
  FNUP: 33,
  FNDOWN: 34
};
var menuPropTypes = __chunk_1._objectSpread({}, __chunk_5.navigationPropTypes, {
  children: PropTypes.node.isRequired,
  isHorizontal: PropTypes.bool
});
var menuDefaultProps = __chunk_1._objectSpread({}, __chunk_5.navigationDefaultProps, {
  isHorizontal: false,
  role: 'menu',
  setInitialFocus: true
});
var Menu =
/*#__PURE__*/
function (_React$Component) {
  __chunk_1._inheritsLoose(Menu, _React$Component);

  function Menu() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    __chunk_1._defineProperty(__chunk_1._assertThisInitialized(_this), "menu", React.createRef());

    __chunk_1._defineProperty(__chunk_1._assertThisInitialized(_this), "state", {
      activeItemIndex: -1
    });

    __chunk_1._defineProperty(__chunk_1._assertThisInitialized(_this), "componentDidUpdate", function (prevProps) {
      var _this$props = _this.props,
          context = _this$props.context,
          setInitialFocus = _this$props.setInitialFocus;
      var prevContext = prevProps.context;

      if (setInitialFocus && context && prevContext && context.isVisible !== prevContext.isVisible) {
        var menuItems = _this.menu.current && _this.menu.current.querySelectorAll('[role=menuitem]:not(:disabled)') || [];
        var startAtFirst = !context.startAt || context.startAt === 'first';
        requestAnimationFrame(function () {
          var focusedItem = menuItems[startAtFirst ? 0 : menuItems.length - 1];

          if (focusedItem) {
            // @ts-ignore
            focusedItem.focus();
          }
        });
      }
    });

    __chunk_1._defineProperty(__chunk_1._assertThisInitialized(_this), "handleKeyDown", function (e) {
      var prevActiveItemIndex = _this.state.activeItemIndex;
      var menuItems = _this.menu.current && _this.menu.current.querySelectorAll('[role=menuitem]:not(:disabled)') || [];

      if (Object.values(KEYS).some(function (key) {
        return e.keyCode === key;
      })) {
        var activeItemIndex = prevActiveItemIndex;
        e.preventDefault();

        if (e.keyCode === KEYS.DOWN || e.keyCode === KEYS.RIGHT) {
          activeItemIndex = prevActiveItemIndex + 1;

          if (activeItemIndex >= menuItems.length) {
            activeItemIndex = 0;
          }
        } else if (e.keyCode === KEYS.UP || e.keyCode === KEYS.LEFT) {
          activeItemIndex = prevActiveItemIndex - 1;

          if (activeItemIndex < 0) {
            activeItemIndex = menuItems.length - 1;
          }
        } else if (e.keyCode === KEYS.HOME || e.keyCode === KEYS.FNUP) {
          activeItemIndex = 0;
        } else if (e.keyCode === KEYS.END || e.keyCode === KEYS.FNDOWN) {
          activeItemIndex = menuItems.length - 1;
        }

        if (activeItemIndex > -1 && menuItems[activeItemIndex]) {
          // @ts-ignore
          menuItems[activeItemIndex].focus();

          _this.setState({
            activeItemIndex: activeItemIndex
          });
        }
      }
    });

    __chunk_1._defineProperty(__chunk_1._assertThisInitialized(_this), "handleFocus", function () {
      var setInitialFocus = _this.props.setInitialFocus;
      var menuItems = _this.menu.current && _this.menu.current.querySelectorAll('[role=menuitem]') || [];
      var activeItemIndex = setInitialFocus ? 0 : -1; // @ts-ignore

      menuItems.forEach(function (item, i) {
        if (document.activeElement && document.activeElement.isEqualNode(item)) {
          activeItemIndex = i;
        }
      });

      _this.setState({
        activeItemIndex: activeItemIndex
      });
    });

    __chunk_1._defineProperty(__chunk_1._assertThisInitialized(_this), "render", function () {
      var _this$props2 = _this.props,
          children = _this$props2.children,
          isHorizontal = _this$props2.isHorizontal,
          props = __chunk_1._objectWithoutPropertiesLoose(_this$props2, ["children", "isHorizontal"]);

      return React.createElement(styled$4.default, __chunk_1._extends({
        elementRef: _this.menu,
        "aria-orientation": isHorizontal ? 'horizontal' : 'vertical',
        isHorizontal: isHorizontal,
        onKeyDown: _this.handleKeyDown,
        onFocus: _this.handleFocus
      }, props), children);
    });

    return _this;
  }

  return Menu;
}(React.Component); // @ts-ignore

__chunk_1._defineProperty(Menu, "propTypes", menuPropTypes);

__chunk_1._defineProperty(Menu, "defaultProps", menuDefaultProps);

var C = MenuContext.withMenuContext(Menu);
C.Button = MenuButton.default;
C.Divider = MenuDivider.default;
C.Group = MenuGroup.default;
C.Item = MenuItem.default;
C.Popover = MenuPopover.default;
C.Trigger = MenuTrigger.default;

exports.MenuContext = MenuContext.default;
exports.MenuProvider = MenuContext.MenuProvider;
exports.withMenuContext = MenuContext.withMenuContext;
exports.MenuButton = MenuButton.default;
exports.menuButtonDefaultProps = MenuButton.menuButtonDefaultProps;
exports.menuButtonPropTypes = MenuButton.menuButtonPropTypes;
exports.MenuDivider = MenuDivider.default;
exports.MenuGroup = MenuGroup.default;
exports.menuGroupDefaultProps = MenuGroup.menuGroupDefaultProps;
exports.menuGroupPropTypes = MenuGroup.menuGroupPropTypes;
exports.MenuItem = MenuItem.default;
exports.menuItemDefaultProps = MenuItem.menuItemDefaultProps;
exports.menuItemPropTypes = MenuItem.menuItemPropTypes;
exports.MenuPopover = MenuPopover.default;
exports.menuPopoverDefaultProps = MenuPopover.menuPopoverDefaultProps;
exports.menuPopoverPropTypes = MenuPopover.menuPopoverPropTypes;
exports.Menu = C;
exports.default = C;
exports.menuDefaultProps = menuDefaultProps;
exports.menuPropTypes = menuPropTypes;
