'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var styled = require('reakit/styled');
var styled__default = _interopDefault(styled);
var styledTools = require('styled-tools');
require('styled-selector');
require('../styled/selector.js');
require('lodash/get');
var space = require('../styled/space.js');
var index$2 = require('../styled/index.js');
var _Overlay = _interopDefault(require('reakit/Overlay'));

var getPlacementAttributes = function getPlacementAttributes(props) {
  if (!props.placement) return null;

  var getHiddenAttributes = function getHiddenAttributes(_ref) {
    var transformX = _ref.transformX,
        transformY = _ref.transformY;
    return function (props) {
      return styled.css(["&[aria-hidden='true']{transform:", ";}"], "translate3d(" + (props.slide ? transformX : '0') + ", " + (props.slide ? transformY : '0') + ", 0px) " + (props.expand ? 'scale(0.01)' : ''));
    };
  };

  var placementAttributes = {
    // @ts-ignore
    top: styled.css(["top:", "em;left:50%;transform:translate3d(-50%,0,0px);", ";"], space.default(5), getHiddenAttributes({
      transformX: '-50%',
      transformY: 'calc(50% - 100%)'
    })),
    // @ts-ignore
    bottom: styled.css(["bottom:", "em;left:50%;transform:translate3d(-50%,0,0px);", ";"], space.default(5), getHiddenAttributes({
      transformX: '-50%',
      transformY: 'calc(50% + 100%)'
    })),
    // @ts-ignore
    left: styled.css(["top:50%;left:", "em;transform:translate3d(0px,-50%,0px);", ";"], space.default(5), getHiddenAttributes({
      transformX: 'calc(50% - 100%)',
      transformY: '-50%'
    })),
    // @ts-ignore
    right: styled.css(["top:50%;right:", "em;transform:translate3d(0px,-50%,0px);", ";"], space.default(5), getHiddenAttributes({
      transformX: 'calc(50% + 100%)',
      transformY: '-50%'
    })),
    // @ts-ignore
    'top-start': styled.css(["top:", "em;left:", "em;transform:translate3d(0,0,0px);", ";"], space.default(5), space.default(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% - 100%)'
    })),
    // @ts-ignore
    'top-end': styled.css(["top:", "em;right:", "em;transform:translate3d(0,0,0px);", ";"], space.default(5), space.default(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% - 100%)'
    })),
    // @ts-ignore
    'bottom-end': styled.css(["bottom:", "em;right:", "em;transform:translate3d(0,0,0px);", ";"], space.default(5), space.default(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% + 100%)'
    })),
    // @ts-ignore
    'bottom-start': styled.css(["bottom:", "em;left:", "em;transform:translate3d(0,0,0px);", ";"], space.default(5), space.default(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% + 100%)'
    }))
  };
  return styled.css(["top:unset;left:unset;", ";"], placementAttributes[props.placement]);
};
var OverlayHide = index$2.default(_Overlay.Hide).withConfig({
  displayName: "styled__OverlayHide",
  componentId: "sc-1t69wy-0"
})(["", ";"], styledTools.theme('fannypack.Overlay.Hide.base'));
var OverlayShow = index$2.default(_Overlay.Show).withConfig({
  displayName: "styled__OverlayShow",
  componentId: "sc-1t69wy-1"
})(["", ";"], styledTools.theme('fannypack.Overlay.Show.base'));
var OverlayToggle = index$2.default(_Overlay.Toggle).withConfig({
  displayName: "styled__OverlayToggle",
  componentId: "sc-1t69wy-2"
})(["", ";"], styledTools.theme('fannypack.Overlay.Toggle.base'));
var Overlay = index$2.default(_Overlay).withConfig({
  displayName: "styled__Overlay",
  componentId: "sc-1t69wy-3"
})(["&{", ";}", ";"], getPlacementAttributes, styledTools.theme('fannypack.Overlay.base'));

exports.Overlay = Overlay;
exports.OverlayHide = OverlayHide;
exports.OverlayShow = OverlayShow;
exports.OverlayToggle = OverlayToggle;
exports.default = Overlay;
exports.getPlacementAttributes = getPlacementAttributes;
