'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = require('prop-types');
var styled = require('reakit/styled');
var styled__default = _interopDefault(styled);
require('styled-tools');
require('styled-selector');
require('../styled/selector.js');
var _get = _interopDefault(require('lodash/get'));
require('../styled/space.js');
require('../styled/index.js');
var __chunk_1 = require('../chunk-c300b528.js');
var reakit = require('reakit');
var Media = _interopDefault(require('react-media'));

var initialState = {
  isSidebarOpen: true,
  isCollapsed: false,
  isMinimized: false
};
var actions = {
  openSidebar: function openSidebar() {
    return function () {
      return {
        isSidebarOpen: true
      };
    };
  },
  closeSidebar: function closeSidebar() {
    return function () {
      return {
        isSidebarOpen: false
      };
    };
  },
  maximizeSidebar: function maximizeSidebar() {
    return function () {
      return {
        isMinimized: false
      };
    };
  },
  minimizeSidebar: function minimizeSidebar() {
    return function () {
      return {
        isMinimized: true
      };
    };
  },
  handleChangeCollapsed: function handleChangeCollapsed(isCollapsed) {
    return function (state) {
      return {
        isCollapsed: isCollapsed,
        isMinimized: isCollapsed ? false : state.isMinimized,
        isSidebarOpen: !isCollapsed
      };
    };
  }
};
var PageContainer = function PageContainer(_ref) {
  var children = _ref.children,
      theme = _ref.theme;

  var breakpoint = _get(theme, 'fannypack.Page.collapseBreakpoint');

  var breakpointPx = _get(theme, "fannypack.layout." + breakpoint + "Breakpoint");

  return React.createElement(reakit.Container, {
    context: "page",
    initialState: initialState,
    actions: actions
  }, function (page) {
    return React.createElement(React.Fragment, null, React.createElement(Media, {
      query: "(max-width: " + breakpointPx + "px)",
      onChange: page.handleChangeCollapsed
    }), children(page));
  });
};
PageContainer.propTypes = {
  children: PropTypes.func.isRequired,
  theme: PropTypes.object
};
PageContainer.defaultProps = {
  theme: {}
};

var _PageContainer = styled.withTheme(PageContainer);
var withPage = function withPage(C) {
  return function (props) {
    return React.createElement(_PageContainer, null, function (page) {
      return React.createElement(C, __chunk_1._extends({
        page: page
      }, props));
    });
  };
};

exports.PageContainer = PageContainer;
exports.default = _PageContainer;
exports.withPage = withPage;
