'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = require('prop-types');
var __chunk_1 = require('../chunk-c300b528.js');
var Box = _interopDefault(require('reakit/Box'));
require('reakit/Block');
require('reakit/Inline');
require('reakit/InlineBlock');
require('reakit/Flex');
require('reakit/InlineFlex');
require('reakit/Grid');
var _omit = _interopDefault(require('lodash/omit'));
var fields = require('../adaptors/fields.js');
var __chunk_12 = require('../chunk-7918bb15.js');
var styled = require('./styled.js');

var Textarea = function Textarea(_ref) {
  var a11yId = _ref.a11yId,
      a11yLabel = _ref.a11yLabel,
      isLoading = _ref.isLoading,
      isRequired = _ref.isRequired,
      size = _ref.size,
      state = _ref.state,
      textareaRef = _ref.textareaRef,
      props = __chunk_1._objectWithoutPropertiesLoose(_ref, ["a11yId", "a11yLabel", "isLoading", "isRequired", "size", "state", "textareaRef"]);

  return React.createElement(Box, {
    relative: true
  }, React.createElement(styled.default, __chunk_1._extends({
    use: "textarea",
    "aria-invalid": state === 'danger',
    "aria-label": a11yLabel,
    "aria-required": isRequired,
    id: a11yId,
    elementRef: textareaRef,
    styledSize: size,
    state: state
  }, props)), isLoading && React.createElement(styled.LoadingSpinner, {
    color: "text"
  }));
};
Textarea.Formik = fields.formikField(Textarea);
Textarea.ReduxForm = fields.reduxFormField(Textarea);
var textareaPropTypes = {
  a11yId: PropTypes.string,
  a11yLabel: PropTypes.string,
  autoComplete: PropTypes.string,
  autoFocus: PropTypes.bool,
  className: PropTypes.string,
  defaultValue: PropTypes.string,
  disabled: PropTypes.bool,
  isFullWidth: PropTypes.bool,
  isLoading: PropTypes.bool,
  isRequired: PropTypes.bool,
  name: PropTypes.string,
  size: PropTypes.string,
  maxLength: PropTypes.number,
  minLength: PropTypes.number,
  pattern: PropTypes.string,
  placeholder: PropTypes.string,
  readOnly: PropTypes.bool,
  rows: PropTypes.number,
  spellCheck: PropTypes.bool,
  state: PropTypes.string,
  textareaRef: PropTypes.object,
  value: PropTypes.string,
  onBlur: PropTypes.func,
  onChange: PropTypes.func,
  onFocus: PropTypes.func
};
Textarea.propTypes = textareaPropTypes;
var textareaDefaultProps = {
  a11yId: undefined,
  a11yLabel: undefined,
  autoComplete: undefined,
  autoFocus: false,
  className: undefined,
  defaultValue: undefined,
  disabled: false,
  isFullWidth: false,
  isLoading: false,
  isRequired: false,
  maxLength: undefined,
  minLength: undefined,
  name: undefined,
  onBlur: undefined,
  onChange: undefined,
  onFocus: undefined,
  pattern: undefined,
  placeholder: undefined,
  readOnly: undefined,
  rows: 3,
  spellCheck: undefined,
  size: 'default',
  state: undefined,
  textareaRef: undefined,
  value: undefined
};
Textarea.defaultProps = textareaDefaultProps; // @ts-ignore

var TextareaField = function TextareaField(_ref) {
  var a11yId = _ref.a11yId,
      a11yLabel = _ref.a11yLabel,
      autoComplete = _ref.autoComplete,
      autoFocus = _ref.autoFocus,
      defaultValue = _ref.defaultValue,
      description = _ref.description,
      disabled = _ref.disabled,
      hint = _ref.hint,
      isFullWidth = _ref.isFullWidth,
      isLoading = _ref.isLoading,
      isOptional = _ref.isOptional,
      isRequired = _ref.isRequired,
      label = _ref.label,
      name = _ref.name,
      maxLength = _ref.maxLength,
      minLength = _ref.minLength,
      pattern = _ref.pattern,
      placeholder = _ref.placeholder,
      readOnly = _ref.readOnly,
      rows = _ref.rows,
      spellCheck = _ref.spellCheck,
      size = _ref.size,
      state = _ref.state,
      textareaProps = _ref.textareaProps,
      textareaRef = _ref.textareaRef,
      validationText = _ref.validationText,
      value = _ref.value,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      props = __chunk_1._objectWithoutPropertiesLoose(_ref, ["a11yId", "a11yLabel", "autoComplete", "autoFocus", "defaultValue", "description", "disabled", "hint", "isFullWidth", "isLoading", "isOptional", "isRequired", "label", "name", "maxLength", "minLength", "pattern", "placeholder", "readOnly", "rows", "spellCheck", "size", "state", "textareaProps", "textareaRef", "validationText", "value", "onBlur", "onChange", "onFocus"]);

  return React.createElement(__chunk_12.FieldWrapper, __chunk_1._extends({
    a11yId: a11yId,
    description: description,
    hint: hint,
    isOptional: isOptional,
    isRequired: isRequired,
    label: label,
    state: state,
    validationText: validationText
  }, props), function (_ref2) {
    var elementProps = _ref2.elementProps;
    return React.createElement(Textarea, __chunk_1._extends({
      a11yId: a11yId,
      a11yLabel: a11yLabel,
      autoComplete: autoComplete,
      autoFocus: autoFocus,
      defaultValue: defaultValue,
      disabled: disabled,
      isFullWidth: isFullWidth,
      isLoading: isLoading,
      isRequired: isRequired,
      name: name,
      size: size,
      maxLength: maxLength,
      minLength: minLength,
      pattern: pattern,
      placeholder: placeholder,
      readOnly: readOnly,
      rows: rows,
      spellCheck: spellCheck,
      state: state,
      textareaRef: textareaRef,
      value: value,
      onBlur: onBlur,
      onChange: onChange,
      onFocus: onFocus
    }, elementProps, textareaProps));
  });
};
TextareaField.Formik = fields.formikField(TextareaField, {
  hasFieldWrapper: true
});
TextareaField.ReduxForm = fields.reduxFormField(TextareaField, {
  hasFieldWrapper: true
});
var textareaFieldPropTypes = __chunk_1._objectSpread({
  textareaProps: PropTypes.shape(textareaPropTypes)
}, _omit(__chunk_12.fieldWrapperPropTypes, 'children'), textareaPropTypes);
TextareaField.propTypes = textareaFieldPropTypes;
var textareaFieldDefaultProps = __chunk_1._objectSpread({
  textareaProps: {}
}, __chunk_12.fieldWrapperDefaultProps, textareaDefaultProps);
TextareaField.defaultProps = textareaFieldDefaultProps; // @ts-ignore

var C = TextareaField;

exports.C = C;
exports.Textarea = Textarea;
exports.TextareaField = TextareaField;
exports.textareaDefaultProps = textareaDefaultProps;
exports.textareaFieldDefaultProps = textareaFieldDefaultProps;
exports.textareaFieldPropTypes = textareaFieldPropTypes;
exports.textareaPropTypes = textareaPropTypes;
