'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = require('prop-types');
var props = require('../types/props.js');
var __chunk_1 = require('../chunk-c300b528.js');
var reakit = require('reakit');
var _uniqueId = _interopDefault(require('lodash/uniqueId'));

var initialState = {
  autoDismissTimeout: 5000,
  toasts: []
};

var add = function add(toast) {
  return function (_ref) {
    var setState = _ref.setState,
        state = _ref.state;
    var placement = state.props.placement;

    var key = _uniqueId('toast-');

    var autoDismissTimeout = typeof toast.autoDismissTimeout === 'number' ? toast.autoDismissTimeout : state.autoDismissTimeout;
    setState(function (state) {
      return {
        toasts: [].concat(placement.includes('bottom') ? state.toasts : [], [__chunk_1._objectSpread({
          key: key,
          autoDismissTimeout: autoDismissTimeout
        }, toast)], !placement.includes('bottom') ? state.toasts : [])
      };
    });

    if (autoDismissTimeout > 0) {
      setTimeout(function () {
        return setState(function (state) {
          return {
            toasts: state.toasts.filter(function (toast) {
              return toast.key !== key;
            })
          };
        });
      }, toast.autoDismissTimeout || state.autoDismissTimeout);
    }
  };
};

var effects = {
  add: add,
  info: function info(toast) {
    return add(__chunk_1._objectSpread({}, toast, {
      type: 'info'
    }));
  },
  success: function success(toast) {
    return add(__chunk_1._objectSpread({}, toast, {
      type: 'success'
    }));
  },
  danger: function danger(toast) {
    return add(__chunk_1._objectSpread({}, toast, {
      type: 'danger'
    }));
  },
  warning: function warning(toast) {
    return add(__chunk_1._objectSpread({}, toast, {
      type: 'warning'
    }));
  }
};
var actions = {
  remove: function remove(_ref2) {
    var key = _ref2.key;
    return function (state) {
      return {
        toasts: state.toasts.filter(function (toast) {
          return toast.key !== key;
        })
      };
    };
  }
};
var ToastContainer = function ToastContainer(_ref3) {
  var children = _ref3.children,
      props = __chunk_1._objectWithoutPropertiesLoose(_ref3, ["children"]);

  return React.createElement(reakit.Container, {
    context: "toasts",
    initialState: __chunk_1._objectSpread({}, initialState, {
      props: props
    }),
    actions: actions,
    effects: effects
  }, children);
};
var toastContainerPropTypes = {
  children: PropTypes.func.isRequired,
  placement: props.placementPropType
};
ToastContainer.propTypes = toastContainerPropTypes;
var toastContainerDefaultProps = {
  placement: 'top-end'
};
ToastContainer.defaultProps = toastContainerDefaultProps;
var withToasts = function withToasts(C) {
  return function (props) {
    return React.createElement(ToastContainer, null, function (toast) {
      return React.createElement(C, __chunk_1._extends({
        toast: toast
      }, props));
    });
  };
};

exports.ToastContainer = ToastContainer;
exports.default = ToastContainer;
exports.toastContainerDefaultProps = toastContainerDefaultProps;
exports.toastContainerPropTypes = toastContainerPropTypes;
exports.withToasts = withToasts;
