'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = require('prop-types');
var styled = require('reakit/styled');
var styled__default = _interopDefault(styled);
var _get = _interopDefault(require('lodash/get'));
require('./styled/index.js');
var __chunk_1 = require('./chunk-c300b528.js');
var propTypeUtils = _interopDefault(require('airbnb-prop-types'));
var parseIcons = require('./parseIcons.js');
var styled$1 = require('./Icon/styled.js');

var Icon = function Icon(_ref) {
  var a11yHidden = _ref.a11yHidden,
      a11yLabel = _ref.a11yLabel,
      children = _ref.children,
      icon = _ref.icon,
      _size = _ref.size,
      theme = _ref.theme,
      type = _ref.type,
      props = __chunk_1._objectWithoutPropertiesLoose(_ref, ["a11yHidden", "a11yLabel", "children", "icon", "size", "theme", "type"]);

  var size = _get(theme, "fannypack.fontSizes[" + (_size || '') + "]", 1);

  var newIcon = _get(theme, "fannypack.Icon.iconNames[" + icon + "]") || icon;

  var icons = _get(theme, "fannypack.Icon.icons", {}); // @ts-ignore


  var iconInfo = icons[newIcon];

  if (type) {
    // @ts-ignore
    var parsedIcons = parseIcons.default([icon], {
      type: type
    });
    iconInfo = Object.entries(parsedIcons)[0][1];
  } else if (typeof icon === 'object') {
    iconInfo = icon;
  }

  var _iconInfo = iconInfo,
      viewBoxWidth = _iconInfo.viewBoxWidth,
      viewBoxHeight = _iconInfo.viewBoxHeight,
      paths = _iconInfo.paths;
  return (// @ts-ignore
    React.createElement(styled$1.default, __chunk_1._extends({
      use: "svg",
      "aria-hidden": a11yHidden,
      role: "img" // @ts-ignore
      ,
      size: size,
      viewBox: "0 0 " + viewBoxWidth + " " + viewBoxHeight
    }, props), a11yLabel && React.createElement("title", null, a11yLabel), paths.map(function (path) {
      return React.createElement("path", {
        key: path,
        d: path,
        fill: "currentColor",
        fillRule: "evenodd"
      });
    }))
  );
};
var iconPropTypes = {
  a11yHidden: propTypeUtils.mutuallyExclusiveProps(PropTypes.bool, 'a11yHidden', 'a11yLabel'),
  // eslint-disable-line
  a11yLabel: propTypeUtils.mutuallyExclusiveProps(PropTypes.string, 'a11yHidden', 'a11yLabel'),
  // eslint-disable-line
  children: PropTypes.node,
  color: PropTypes.string,
  className: PropTypes.string,
  icon: PropTypes.oneOfType([PropTypes.string, PropTypes.shape({
    viewBoxHeight: PropTypes.number,
    viewBoxWidth: PropTypes.number,
    paths: PropTypes.arrayOf(PropTypes.string)
  })]),
  size: PropTypes.string,
  theme: PropTypes.object,
  // eslint-disable-line
  type: PropTypes.oneOf(['font-awesome', 'font-awesome-standalone'])
};
Icon.propTypes = iconPropTypes;
var iconDefaultProps = {
  children: null,
  className: undefined,
  color: undefined,
  icon: undefined,
  size: 'default',
  type: undefined
};
Icon.defaultProps = iconDefaultProps; // @ts-ignore

var C = styled.withTheme(Icon);

exports.Icon = C;
exports.iconDefaultProps = iconDefaultProps;
exports.iconPropTypes = iconPropTypes;
