import * as React from 'react';
import * as PropTypes from 'prop-types';
import { LabelProps as ReakitLabelProps } from 'reakit/ts';
export declare type LocalCheckboxProps = {
    /** Automatically focus on the checkbox */
    autoFocus?: boolean;
    checked?: boolean;
    checkboxRef?: React.RefObject<any>;
    className?: string;
    /** Is the checkbox checked by default? */
    defaultChecked?: boolean;
    /** Disables the checkbox */
    disabled?: boolean;
    /** ID for the checkbox */
    id?: string;
    indeterminate?: boolean;
    /** Makes the checkbox required and sets aria-invalid to true */
    isRequired?: boolean;
    /** Checkbox label */
    label?: string;
    name?: string;
    /** State of the checkbox. Can be any color in the palette. */
    state?: string;
    /** Initial value of the checkbox */
    value?: boolean | string;
    /** Function to invoke when focus is lost */
    onBlur?: React.FocusEventHandler<HTMLInputElement>;
    /** Function to invoke when checkbox has changed */
    onChange?: React.FormEventHandler<HTMLInputElement>;
    /** Function to invoke when checkbox is focused */
    onFocus?: React.FocusEventHandler<HTMLInputElement>;
};
export declare type CheckboxProps = LocalCheckboxProps & ReakitLabelProps;
export declare type CheckboxComponents = {
    Formik: React.FunctionComponent<CheckboxProps>;
    ReduxForm: React.FunctionComponent<CheckboxProps>;
};
export declare const Checkbox: React.FunctionComponent<LocalCheckboxProps> & CheckboxComponents;
export declare const checkboxPropTypes: {
    autoFocus: PropTypes.Requireable<boolean>;
    checked: PropTypes.Requireable<boolean>;
    className: PropTypes.Requireable<string>;
    checkboxRef: PropTypes.Validator<React.RefObject<any>>;
    defaultChecked: PropTypes.Requireable<boolean>;
    disabled: PropTypes.Requireable<boolean>;
    id: PropTypes.Requireable<string>;
    indeterminate: PropTypes.Requireable<boolean>;
    isRequired: PropTypes.Requireable<boolean>;
    label: PropTypes.Requireable<string>;
    name: PropTypes.Requireable<string>;
    state: PropTypes.Requireable<string>;
    value: PropTypes.Requireable<string | boolean>;
    onBlur: PropTypes.Requireable<(...args: any[]) => any>;
    onChange: PropTypes.Requireable<(...args: any[]) => any>;
    onFocus: PropTypes.Requireable<(...args: any[]) => any>;
};
export declare const checkboxDefaultProps: {
    autoFocus: boolean;
    checked: any;
    className: any;
    checkboxRef: any;
    defaultChecked: any;
    disabled: boolean;
    id: any;
    indeterminate: boolean;
    isRequired: boolean;
    label: any;
    onBlur: any;
    onChange: any;
    onFocus: any;
    name: any;
    state: any;
    value: any;
};
declare const C: React.FunctionComponent<CheckboxProps> & CheckboxComponents;
export default C;
