import * as React from 'react';
import * as PropTypes from 'prop-types';
import { Omit } from '../types';
import { ActionButtonsProps } from '../Button/ActionButtons';
import { ButtonProps } from '../Button/Button';
import { DialogDialogProps, LocalDialogDialogProps } from './DialogDialog';
import { DialogContentProps } from './DialogContent';
import { DialogHeaderProps } from './DialogHeader';
import { DialogFooterProps } from './DialogFooter';
import { DialogTitleProps } from './DialogTitle';
import { DialogCloseProps } from './DialogClose';
import { DialogIconProps } from './DialogIcon';
export declare type LocalDialogProps = LocalDialogDialogProps & {
    actionButtonsProps?: ActionButtonsProps;
    a11yDescriptionId?: string;
    a11yTitleId?: string;
    children: React.ReactNode;
    className?: string;
    closeButtonProps?: Omit<ButtonProps, 'children'>;
    footer?: string | React.ReactElement<any>;
    hasScroll?: boolean;
    onClickClose?: () => void;
    showActionButtons?: boolean;
    showCloseButton?: boolean;
    title?: string | React.ReactElement<any>;
    type?: string;
};
export declare type DialogProps = LocalDialogProps & DialogDialogProps;
export declare type DialogComponents = {
    Dialog: React.FunctionComponent<DialogDialogProps>;
    Content: React.FunctionComponent<DialogContentProps>;
    Header: React.FunctionComponent<DialogHeaderProps>;
    Footer: React.FunctionComponent<DialogFooterProps>;
    Title: React.FunctionComponent<DialogTitleProps>;
    Close: React.FunctionComponent<DialogCloseProps>;
    Icon: React.FunctionComponent<DialogIconProps>;
};
export declare const Dialog: React.FunctionComponent<LocalDialogProps> & DialogComponents;
export declare const dialogPropTypes: {
    children: PropTypes.Validator<PropTypes.ReactNodeLike>;
    border: PropTypes.Validator<boolean | "shadow">;
    className: PropTypes.Requireable<string>;
    isFullWidth: PropTypes.Requireable<boolean>;
    elevation: PropTypes.Requireable<string>;
    a11yDescriptionId: PropTypes.Requireable<string>;
    a11yTitleId: PropTypes.Requireable<string>;
    kind: PropTypes.Validator<"alert">;
    actionButtonsProps: PropTypes.Requireable<PropTypes.InferProps<{
        addonButtons: PropTypes.Requireable<PropTypes.ReactElementLike>;
        cancelProps: PropTypes.Requireable<PropTypes.InferProps<any>>;
        cancelText: PropTypes.Requireable<string>;
        className: PropTypes.Requireable<string>;
        isLoading: PropTypes.Requireable<boolean>;
        onClickSubmit: PropTypes.Requireable<(...args: any[]) => any>;
        onClickCancel: PropTypes.Requireable<(...args: any[]) => any>;
        palette: PropTypes.Requireable<string>;
        submitProps: PropTypes.Requireable<PropTypes.InferProps<any>>;
        submitText: PropTypes.Requireable<string>;
        type: PropTypes.Requireable<string>;
    }>>;
    closeButtonProps: PropTypes.Requireable<PropTypes.InferProps<any>>;
    footer: PropTypes.Requireable<string | PropTypes.ReactElementLike>;
    hasScroll: PropTypes.Requireable<boolean>;
    onClickClose: PropTypes.Requireable<(...args: any[]) => any>;
    showActionButtons: PropTypes.Requireable<boolean>;
    showCloseButton: PropTypes.Requireable<boolean>;
    title: PropTypes.Requireable<string | PropTypes.ReactElementLike>;
    type: PropTypes.Requireable<string>;
};
export declare const dialogDefaultProps: {
    actionButtonsProps: {};
    a11yDescriptionId: any;
    a11yTitleId: any;
    className: any;
    closeButtonProps: {};
    footer: any;
    hasScroll: boolean;
    onClickClose: any;
    showActionButtons: boolean;
    showCloseButton: boolean;
    title: any;
    type: any;
    border: boolean;
    kind: any;
    children: any;
    isFullWidth: boolean;
    elevation: any;
};
declare const C: React.FunctionComponent<DialogProps> & DialogComponents;
export default C;
