import * as React from 'react';
import * as PropTypes from 'prop-types';
import { ReakitBoxProps } from '../types';
import { ParsedIcon, Opts as ParseIconOpts } from '../parseIcons';
import { Omit } from '../types';
export declare type Props = {
    children?: React.ReactNode;
    /** Color of the icon. Can be a color from the palette, or any other color. */
    color?: string;
    className?: string;
    /** The name of your icon from the free Font Awesome Icon Set (https://fontawesome.com/icons?d=gallery&m=free). */
    icon: string | ParsedIcon;
    /** Size of the icon. */
    size?: string;
    theme?: Object;
    type?: ParseIconOpts['type'];
};
export declare type PropsWithA11yHidden = Props & {
    /** Indicates that this element should be skipped by assistive technologies. */
    a11yHidden: boolean;
};
export declare type PropsWithA11yLabel = Props & {
    /** A label for the icon which can be read by screen readers. This is required if a11yHidden is false. */
    a11yLabel: string;
};
export declare type LocalIconProps = PropsWithA11yHidden | PropsWithA11yLabel;
export declare type IconProps = Omit<ReakitBoxProps, 'size'> & LocalIconProps;
export declare const Icon: React.FunctionComponent<LocalIconProps>;
export declare const iconPropTypes: {
    a11yHidden: any;
    a11yLabel: any;
    children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
    color: PropTypes.Requireable<string>;
    className: PropTypes.Requireable<string>;
    icon: PropTypes.Validator<string | ParsedIcon>;
    size: PropTypes.Requireable<string>;
    theme: PropTypes.Requireable<object>;
    type: PropTypes.Validator<"font-awesome" | "font-awesome-standalone">;
};
export declare const iconDefaultProps: {
    children: any;
    className: any;
    color: any;
    icon: any;
    size: string;
    type: any;
};
declare const C: React.FunctionComponent<IconProps>;
export default C;
