import * as React from 'react';
import * as PropTypes from 'prop-types';
import { InputProps as ReakitInputProps } from 'reakit/ts';
import { Omit, Size } from '../types';
import { IconProps } from '../Icon/Icon';
export declare type LocalInputProps = {
    after?: React.ReactElement<any>;
    /** An accessible identifier for the input */
    a11yId?: string;
    /** An accessible label for the input */
    a11yLabel?: string;
    autoComplete?: string;
    /** Automatically focus on the input */
    autoFocus?: boolean;
    before?: React.ReactElement<any>;
    children?: React.ReactNode;
    className?: string;
    /** Default value of the input */
    defaultValue?: string | string[];
    /** Disables the input */
    disabled?: boolean;
    inputProps?: Omit<ReakitInputProps, 'ref'>;
    inputRef?: React.RefObject<any>;
    /** Adds a cute loading indicator to the input field */
    isLoading?: boolean;
    /** Makes the input required and sets aria-invalid to true */
    isRequired?: boolean;
    /** Name of the input field */
    name?: string;
    /** Alters the size of the input. Can be "small", "medium" or "large" */
    size?: Size;
    mask?: string;
    /** The maximum (numeric or date-time) value for the input. Must not be less than its minimum (min attribute) value. */
    max?: number | string;
    /** If the value of the type attribute is text, email, search, password, tel, or url, this attribute specifies the maximum number of characters (in UTF-16 code units) that the user can enter. For other control types, it is ignored. */
    maxLength?: number;
    /** The minimum (numeric or date-time) value for this input, which must not be greater than its maximum (max attribute) value. */
    min?: number | string;
    /** If the value of the type attribute is text, email, search, password, tel, or url, this attribute specifies the minimum number of characters (in UTF-16 code points) that the user can enter. For other control types, it is ignored. */
    minLength?: number;
    /** This prop indicates whether the user can enter more than one value. This attribute only applies when the type attribute is set to email or file. */
    multiple?: boolean;
    /** Regex pattern to apply to the input */
    pattern?: string;
    /** Hint text to display */
    placeholder?: string;
    /** This prop prevents the user from modifying the value of the input. It is ignored if the value of the type attribute is hidden, range, color, checkbox, radio, file, or a button type (such as button or submit). */
    readOnly?: boolean;
    /** Setting the value of this attribute to true indicates that the element needs to have its spelling and grammar checked. The value default indicates that the element is to act according to a default behavior, possibly based on the parent element's own spellcheck value. The value false indicates that the element should not be checked. */
    spellCheck?: boolean;
    /** Works with the min and max attributes to limit the increments at which a numeric or date-time value can be set. */
    step?: number | string;
    /** State of the input. Can be any color in the palette. */
    state?: string;
    /** Specify the type of input. */
    type?: string;
    /** Value of the input */
    value?: string | number | string[];
    /** Function to invoke when focus is lost */
    onBlur?: React.FocusEventHandler<HTMLInputElement>;
    /** Function to invoke when input has changed */
    onChange?: React.FormEventHandler<HTMLInputElement>;
    /** Function to invoke when input is focused */
    onFocus?: React.FocusEventHandler<HTMLInputElement>;
};
export declare type InputProps = Omit<ReakitInputProps, 'size'> & LocalInputProps;
export declare type InputComponents = {
    Icon: React.FunctionComponent<IconProps>;
    Formik: React.FunctionComponent<InputProps>;
    ReduxForm: React.FunctionComponent<InputProps>;
};
export declare const Input: React.FunctionComponent<LocalInputProps> & InputComponents;
export declare const inputPropTypes: {
    after: PropTypes.Requireable<PropTypes.ReactElementLike>;
    a11yId: PropTypes.Requireable<string>;
    a11yLabel: PropTypes.Requireable<string>;
    autoComplete: PropTypes.Requireable<string>;
    autoFocus: PropTypes.Requireable<boolean>;
    before: PropTypes.Requireable<PropTypes.ReactElementLike>;
    children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
    className: PropTypes.Requireable<string>;
    defaultValue: PropTypes.Requireable<string>;
    disabled: PropTypes.Requireable<boolean>;
    inputProps: PropTypes.Validator<Pick<ReakitInputProps, "default" | "left" | "right" | "top" | "bottom" | "accept" | "acceptCharset" | "action" | "allowFullScreen" | "allowTransparency" | "alt" | "async" | "autoComplete" | "autoFocus" | "autoPlay" | "capture" | "cellPadding" | "cellSpacing" | "charSet" | "challenge" | "checked" | "cite" | "classID" | "cols" | "colSpan" | "content" | "controls" | "coords" | "crossOrigin" | "data" | "dateTime" | "defer" | "disabled" | "download" | "encType" | "form" | "formAction" | "formEncType" | "formMethod" | "formNoValidate" | "formTarget" | "frameBorder" | "headers" | "height" | "high" | "href" | "hrefLang" | "htmlFor" | "httpEquiv" | "integrity" | "keyParams" | "keyType" | "kind" | "label" | "list" | "loop" | "low" | "manifest" | "marginHeight" | "marginWidth" | "max" | "maxLength" | "media" | "mediaGroup" | "method" | "min" | "minLength" | "multiple" | "muted" | "name" | "nonce" | "noValidate" | "open" | "optimum" | "pattern" | "placeholder" | "playsInline" | "poster" | "preload" | "readOnly" | "rel" | "required" | "reversed" | "rows" | "rowSpan" | "sandbox" | "scope" | "scoped" | "scrolling" | "seamless" | "selected" | "shape" | "size" | "sizes" | "span" | "src" | "srcDoc" | "srcLang" | "srcSet" | "start" | "step" | "summary" | "target" | "type" | "useMap" | "value" | "width" | "wmode" | "wrap" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "className" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "hidden" | "id" | "lang" | "slot" | "spellCheck" | "style" | "tabIndex" | "title" | "inputMode" | "is" | "radioGroup" | "role" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "color" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "children" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "key" | "alignContent" | "alignSelf" | "alignItems" | "alignmentBaseline" | "all" | "animation" | "animationDelay" | "animationDirection" | "animationDuration" | "animationFillMode" | "animationIterationCount" | "animationName" | "animationPlayState" | "animationTimingFunction" | "appearance" | "azimuth" | "backfaceVisibility" | "background" | "backgroundAttachment" | "backgroundBlendMode" | "backgroundClip" | "backgroundColor" | "backgroundImage" | "backgroundImageTransform" | "backgroundOrigin" | "backgroundPosition" | "backgroundRepeat" | "backgroundSize" | "baselineShift" | "blockSize" | "blockStep" | "blockStepAlign" | "blockStepInsert" | "blockStepRound" | "blockStepSize" | "bookmarkLabel" | "bookmarkLevel" | "bookmarkState" | "border" | "borderBlock" | "borderBlockColor" | "borderBlockEnd" | "borderBlockEndColor" | "borderBlockEndStyle" | "borderBlockEndWidth" | "borderBlockStart" | "borderBlockStartColor" | "borderBlockStartStyle" | "borderBlockStartWidth" | "borderBlockStyle" | "borderBlockWidth" | "borderBottom" | "borderBottomColor" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomStyle" | "borderBottomWidth" | "borderBoundary" | "borderCollapse" | "borderColor" | "borderImage" | "borderImageOutset" | "borderImageRepeat" | "borderImageSlice" | "borderImageSource" | "borderImageTransform" | "borderImageWidth" | "borderInline" | "borderInlineColor" | "borderInlineEnd" | "borderInlineEndColor" | "borderInlineEndStyle" | "borderInlineEndWidth" | "borderInlineStart" | "borderInlineStartColor" | "borderInlineStartStyle" | "borderInlineStartWidth" | "borderInlineStyle" | "borderInlineWidth" | "borderLeft" | "borderLeftColor" | "borderLeftStyle" | "borderLeftWidth" | "borderRadius" | "borderRight" | "borderRightColor" | "borderRightStyle" | "borderRightWidth" | "borderSpacing" | "borderStyle" | "borderTop" | "borderTopColor" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopStyle" | "borderTopWidth" | "borderWidth" | "boxDecorationBreak" | "boxShadow" | "boxSizing" | "boxSnap" | "breakAfter" | "breakBefore" | "breakInside" | "captionSide" | "caret" | "caretAnimation" | "caretColor" | "caretShape" | "chains" | "clear" | "clip" | "clipPath" | "clipRule" | "colorAdjust" | "colorInterpolationFilters" | "columnCount" | "columnFill" | "columnGap" | "columnRule" | "columnRuleColor" | "columnRuleStyle" | "columnRuleWidth" | "columnSpan" | "columnWidth" | "columns" | "contain" | "continue" | "counterIncrement" | "counterReset" | "counterSet" | "cue" | "cueAfter" | "cueBefore" | "cursor" | "direction" | "display" | "dominantBaseline" | "elevation" | "emptyCells" | "fill" | "fillBreak" | "fillColor" | "fillImage" | "fillOpacity" | "fillOrigin" | "fillPosition" | "fillRepeat" | "fillRule" | "fillSize" | "filter" | "flex" | "flexBasis" | "flexDirection" | "flexFlow" | "flexGrow" | "flexShrink" | "flexWrap" | "float" | "floatDefer" | "floatOffset" | "floatReference" | "floodColor" | "floodOpacity" | "flow" | "flowFrom" | "flowInto" | "font" | "fontFamily" | "fontFeatureSettings" | "fontKerning" | "fontLanguageOverride" | "fontMaxSize" | "fontMinSize" | "fontOpticalSizing" | "fontPalette" | "fontPresentation" | "fontSize" | "fontSizeAdjust" | "fontStretch" | "fontStyle" | "fontSynthesis" | "fontVariant" | "fontVariantAlternates" | "fontVariantCaps" | "fontVariantEastAsian" | "fontVariantLigatures" | "fontVariantNumeric" | "fontVariantPosition" | "fontVariationSettings" | "fontWeight" | "footnoteDisplay" | "footnotePolicy" | "gap" | "glyphOrientationVertical" | "grid" | "gridArea" | "gridAutoColumns" | "gridAutoFlow" | "gridAutoRows" | "gridColumn" | "gridColumnEnd" | "gridColumnGap" | "gridColumnStart" | "gridGap" | "gridRow" | "gridRowEnd" | "gridRowGap" | "gridRowStart" | "gridTemplate" | "gridTemplateAreas" | "gridTemplateColumns" | "gridTemplateRows" | "hangingPunctuation" | "hyphenateCharacter" | "hyphenateLimitChars" | "hyphenateLimitLast" | "hyphenateLimitLines" | "hyphenateLimitZone" | "hyphens" | "imageOrientation" | "imageResolution" | "initialLetter" | "initialLetterAlign" | "initialLetterWrap" | "inlineSize" | "inset" | "insetBlock" | "insetBlockEnd" | "insetBlockStart" | "insetInline" | "insetInlineEnd" | "insetInlineStart" | "isolation" | "justifyContent" | "justifyItems" | "justifySelf" | "letterSpacing" | "lightingColor" | "lineBreak" | "lineGrid" | "lineHeight" | "lineHeightStep" | "lineSnap" | "listStyle" | "listStyleImage" | "listStylePosition" | "listStyleType" | "margin" | "marginBlock" | "marginBlockEnd" | "marginBlockStart" | "marginBottom" | "marginInline" | "marginInlineEnd" | "marginInlineStart" | "marginLeft" | "marginRight" | "marginTop" | "marker" | "markerEnd" | "markerKnockoutLeft" | "markerKnockoutRight" | "markerMid" | "markerPattern" | "markerSegment" | "markerSide" | "markerStart" | "marqueeDirection" | "marqueeLoop" | "marqueeSpeed" | "marqueeStyle" | "mask" | "maskBorder" | "maskBorderMode" | "maskBorderOutset" | "maskBorderRepeat" | "maskBorderSlice" | "maskBorderSource" | "maskBorderWidth" | "maskClip" | "maskComposite" | "maskImage" | "maskMode" | "maskOrigin" | "maskPosition" | "maskRepeat" | "maskSize" | "maskType" | "maxBlockSize" | "maxHeight" | "maxInlineSize" | "maxLines" | "maxWidth" | "minBlockSize" | "minHeight" | "minInlineSize" | "minWidth" | "mixBlendMode" | "navDown" | "navLeft" | "navRight" | "navUp" | "objectFit" | "objectPosition" | "offset" | "offsetAfter" | "offsetAnchor" | "offsetBefore" | "offsetDistance" | "offsetEnd" | "offsetPath" | "offsetPosition" | "offsetRotate" | "offsetStart" | "opacity" | "order" | "orphans" | "outline" | "outlineColor" | "outlineOffset" | "outlineStyle" | "outlineWidth" | "overflow" | "overflowStyle" | "overflowWrap" | "overflowX" | "overflowY" | "padding" | "paddingBlock" | "paddingBlockEnd" | "paddingBlockStart" | "paddingBottom" | "paddingInline" | "paddingInlineEnd" | "paddingInlineStart" | "paddingLeft" | "paddingRight" | "paddingTop" | "page" | "pageBreakAfter" | "pageBreakBefore" | "pageBreakInside" | "pause" | "pauseAfter" | "pauseBefore" | "perspective" | "perspectiveOrigin" | "pitch" | "pitchRange" | "placeContent" | "placeItems" | "placeSelf" | "playDuring" | "pointerEvents" | "position" | "presentationLevel" | "quotes" | "regionFragment" | "resize" | "rest" | "restAfter" | "restBefore" | "richness" | "rotation" | "rotationPoint" | "rowGap" | "rubyAlign" | "rubyMerge" | "rubyPosition" | "running" | "scrollBehavior" | "scrollPadding" | "scrollPaddingBlock" | "scrollPaddingBlockEnd" | "scrollPaddingBlockStart" | "scrollPaddingBottom" | "scrollPaddingInline" | "scrollPaddingInlineEnd" | "scrollPaddingInlineStart" | "scrollPaddingLeft" | "scrollPaddingRight" | "scrollPaddingTop" | "scrollSnapAlign" | "scrollSnapMargin" | "scrollSnapMarginBlock" | "scrollSnapMarginBlockEnd" | "scrollSnapMarginBlockStart" | "scrollSnapMarginBottom" | "scrollSnapMarginInline" | "scrollSnapMarginInlineEnd" | "scrollSnapMarginInlineStart" | "scrollSnapMarginLeft" | "scrollSnapMarginRight" | "scrollSnapMarginTop" | "scrollSnapStop" | "scrollSnapType" | "scrollbarGutter" | "shapeImageThreshold" | "shapeInside" | "shapeMargin" | "shapeOutside" | "speak" | "speakAs" | "speakHeader" | "speakNumeral" | "speakPunctuation" | "speechRate" | "stress" | "stringSet" | "stroke" | "strokeAlign" | "strokeAlignment" | "strokeBreak" | "strokeColor" | "strokeDashCorner" | "strokeDashJustify" | "strokeDashadjust" | "strokeDasharray" | "strokeDashcorner" | "strokeDashoffset" | "strokeImage" | "strokeLinecap" | "strokeLinejoin" | "strokeMiterlimit" | "strokeOpacity" | "strokeOrigin" | "strokePosition" | "strokeRepeat" | "strokeSize" | "strokeWidth" | "tabSize" | "tableLayout" | "textAlign" | "textAlignAll" | "textAlignLast" | "textCombineUpright" | "textDecoration" | "textDecorationColor" | "textDecorationLine" | "textDecorationSkip" | "textDecorationStyle" | "textEmphasis" | "textEmphasisColor" | "textEmphasisPosition" | "textEmphasisStyle" | "textIndent" | "textJustify" | "textOrientation" | "textOverflow" | "textShadow" | "textSpaceCollapse" | "textSpaceTrim" | "textSpacing" | "textTransform" | "textUnderlinePosition" | "textWrap" | "transform" | "transformBox" | "transformOrigin" | "transformStyle" | "transition" | "transitionDelay" | "transitionDuration" | "transitionProperty" | "transitionTimingFunction" | "unicodeBidi" | "userSelect" | "verticalAlign" | "visibility" | "voiceBalance" | "voiceDuration" | "voiceFamily" | "voicePitch" | "voiceRange" | "voiceRate" | "voiceStress" | "voiceVolume" | "volume" | "whiteSpace" | "widows" | "willChange" | "wordBreak" | "wordSpacing" | "wordWrap" | "wrapAfter" | "wrapBefore" | "wrapFlow" | "wrapInside" | "wrapThrough" | "writingMode" | "zIndex" | "palette" | "use" | "fixed" | "opaque" | "absolute" | "relative" | "static" | "sticky" | "tone" | "elementRef">>;
    inputRef: PropTypes.Validator<React.RefObject<any>>;
    isLoading: PropTypes.Requireable<boolean>;
    isRequired: PropTypes.Requireable<boolean>;
    name: PropTypes.Requireable<string>;
    size: PropTypes.Validator<Size>;
    mask: PropTypes.Requireable<string>;
    max: PropTypes.Requireable<number>;
    maxLength: PropTypes.Requireable<number>;
    min: PropTypes.Requireable<number>;
    minLength: PropTypes.Requireable<number>;
    multiple: PropTypes.Requireable<boolean>;
    pattern: PropTypes.Requireable<string>;
    placeholder: PropTypes.Requireable<string>;
    readOnly: PropTypes.Requireable<boolean>;
    spellCheck: PropTypes.Requireable<boolean>;
    step: PropTypes.Requireable<number>;
    state: PropTypes.Requireable<string>;
    type: PropTypes.Requireable<string>;
    value: PropTypes.Requireable<string>;
    onBlur: PropTypes.Requireable<(...args: any[]) => any>;
    onChange: PropTypes.Requireable<(...args: any[]) => any>;
    onFocus: PropTypes.Requireable<(...args: any[]) => any>;
};
export declare const inputDefaultProps: Partial<LocalInputProps>;
declare const C: React.FunctionComponent<InputProps> & InputComponents;
export default C;
