import * as React from 'react';
import * as PropTypes from 'prop-types';
import { Omit } from '../types';
import { LocalInputProps, InputProps } from './Input';
import { LocalFieldWrapperProps } from '../FieldWrapper/FieldWrapper';
export declare type LocalInputFieldProps = Omit<LocalFieldWrapperProps, 'children'> & LocalInputProps & {
    /** Addon component to the input (before). Similar to the addon components in Input. */
    addonBefore?: React.ReactElement<any>;
    /** Addon component to the input (after). Similar to the addon components in Input. */
    addonAfter?: React.ReactElement<any>;
    inputProps?: LocalInputProps;
    /** If addonBefore or addonAfter exists, then the addons will render vertically. */
    isVertical?: boolean;
};
export declare type InputFieldProps = LocalInputFieldProps & InputProps;
export declare type InputFieldComponents = {
    Formik: React.FunctionComponent<InputFieldProps>;
    ReduxForm: React.FunctionComponent<InputFieldProps>;
};
export declare const InputField: React.FunctionComponent<LocalInputFieldProps> & InputFieldComponents;
export declare const inputFieldPropTypes: {
    after: PropTypes.Requireable<PropTypes.ReactElementLike>;
    a11yId: PropTypes.Requireable<string>;
    a11yLabel: PropTypes.Requireable<string>;
    autoComplete: PropTypes.Requireable<string>;
    autoFocus: PropTypes.Requireable<boolean>;
    before: PropTypes.Requireable<PropTypes.ReactElementLike>;
    children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
    className: PropTypes.Requireable<string>;
    defaultValue: PropTypes.Requireable<string>;
    disabled: PropTypes.Requireable<boolean>;
    inputProps: PropTypes.Validator<Pick<import("reakit/ts").InputProps, "default" | "left" | "right" | "top" | "bottom" | "accept" | "acceptCharset" | "action" | "allowFullScreen" | "allowTransparency" | "alt" | "async" | "autoComplete" | "autoFocus" | "autoPlay" | "capture" | "cellPadding" | "cellSpacing" | "charSet" | "challenge" | "checked" | "cite" | "classID" | "cols" | "colSpan" | "content" | "controls" | "coords" | "crossOrigin" | "data" | "dateTime" | "defer" | "disabled" | "download" | "encType" | "form" | "formAction" | "formEncType" | "formMethod" | "formNoValidate" | "formTarget" | "frameBorder" | "headers" | "height" | "high" | "href" | "hrefLang" | "htmlFor" | "httpEquiv" | "integrity" | "keyParams" | "keyType" | "kind" | "label" | "list" | "loop" | "low" | "manifest" | "marginHeight" | "marginWidth" | "max" | "maxLength" | "media" | "mediaGroup" | "method" | "min" | "minLength" | "multiple" | "muted" | "name" | "nonce" | "noValidate" | "open" | "optimum" | "pattern" | "placeholder" | "playsInline" | "poster" | "preload" | "readOnly" | "rel" | "required" | "reversed" | "rows" | "rowSpan" | "sandbox" | "scope" | "scoped" | "scrolling" | "seamless" | "selected" | "shape" | "size" | "sizes" | "span" | "src" | "srcDoc" | "srcLang" | "srcSet" | "start" | "step" | "summary" | "target" | "type" | "useMap" | "value" | "width" | "wmode" | "wrap" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "className" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "hidden" | "id" | "lang" | "slot" | "spellCheck" | "style" | "tabIndex" | "title" | "inputMode" | "is" | "radioGroup" | "role" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "color" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "children" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "key" | "alignContent" | "alignSelf" | "alignItems" | "alignmentBaseline" | "all" | "animation" | "animationDelay" | "animationDirection" | "animationDuration" | "animationFillMode" | "animationIterationCount" | "animationName" | "animationPlayState" | "animationTimingFunction" | "appearance" | "azimuth" | "backfaceVisibility" | "background" | "backgroundAttachment" | "backgroundBlendMode" | "backgroundClip" | "backgroundColor" | "backgroundImage" | "backgroundImageTransform" | "backgroundOrigin" | "backgroundPosition" | "backgroundRepeat" | "backgroundSize" | "baselineShift" | "blockSize" | "blockStep" | "blockStepAlign" | "blockStepInsert" | "blockStepRound" | "blockStepSize" | "bookmarkLabel" | "bookmarkLevel" | "bookmarkState" | "border" | "borderBlock" | "borderBlockColor" | "borderBlockEnd" | "borderBlockEndColor" | "borderBlockEndStyle" | "borderBlockEndWidth" | "borderBlockStart" | "borderBlockStartColor" | "borderBlockStartStyle" | "borderBlockStartWidth" | "borderBlockStyle" | "borderBlockWidth" | "borderBottom" | "borderBottomColor" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomStyle" | "borderBottomWidth" | "borderBoundary" | "borderCollapse" | "borderColor" | "borderImage" | "borderImageOutset" | "borderImageRepeat" | "borderImageSlice" | "borderImageSource" | "borderImageTransform" | "borderImageWidth" | "borderInline" | "borderInlineColor" | "borderInlineEnd" | "borderInlineEndColor" | "borderInlineEndStyle" | "borderInlineEndWidth" | "borderInlineStart" | "borderInlineStartColor" | "borderInlineStartStyle" | "borderInlineStartWidth" | "borderInlineStyle" | "borderInlineWidth" | "borderLeft" | "borderLeftColor" | "borderLeftStyle" | "borderLeftWidth" | "borderRadius" | "borderRight" | "borderRightColor" | "borderRightStyle" | "borderRightWidth" | "borderSpacing" | "borderStyle" | "borderTop" | "borderTopColor" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopStyle" | "borderTopWidth" | "borderWidth" | "boxDecorationBreak" | "boxShadow" | "boxSizing" | "boxSnap" | "breakAfter" | "breakBefore" | "breakInside" | "captionSide" | "caret" | "caretAnimation" | "caretColor" | "caretShape" | "chains" | "clear" | "clip" | "clipPath" | "clipRule" | "colorAdjust" | "colorInterpolationFilters" | "columnCount" | "columnFill" | "columnGap" | "columnRule" | "columnRuleColor" | "columnRuleStyle" | "columnRuleWidth" | "columnSpan" | "columnWidth" | "columns" | "contain" | "continue" | "counterIncrement" | "counterReset" | "counterSet" | "cue" | "cueAfter" | "cueBefore" | "cursor" | "direction" | "display" | "dominantBaseline" | "elevation" | "emptyCells" | "fill" | "fillBreak" | "fillColor" | "fillImage" | "fillOpacity" | "fillOrigin" | "fillPosition" | "fillRepeat" | "fillRule" | "fillSize" | "filter" | "flex" | "flexBasis" | "flexDirection" | "flexFlow" | "flexGrow" | "flexShrink" | "flexWrap" | "float" | "floatDefer" | "floatOffset" | "floatReference" | "floodColor" | "floodOpacity" | "flow" | "flowFrom" | "flowInto" | "font" | "fontFamily" | "fontFeatureSettings" | "fontKerning" | "fontLanguageOverride" | "fontMaxSize" | "fontMinSize" | "fontOpticalSizing" | "fontPalette" | "fontPresentation" | "fontSize" | "fontSizeAdjust" | "fontStretch" | "fontStyle" | "fontSynthesis" | "fontVariant" | "fontVariantAlternates" | "fontVariantCaps" | "fontVariantEastAsian" | "fontVariantLigatures" | "fontVariantNumeric" | "fontVariantPosition" | "fontVariationSettings" | "fontWeight" | "footnoteDisplay" | "footnotePolicy" | "gap" | "glyphOrientationVertical" | "grid" | "gridArea" | "gridAutoColumns" | "gridAutoFlow" | "gridAutoRows" | "gridColumn" | "gridColumnEnd" | "gridColumnGap" | "gridColumnStart" | "gridGap" | "gridRow" | "gridRowEnd" | "gridRowGap" | "gridRowStart" | "gridTemplate" | "gridTemplateAreas" | "gridTemplateColumns" | "gridTemplateRows" | "hangingPunctuation" | "hyphenateCharacter" | "hyphenateLimitChars" | "hyphenateLimitLast" | "hyphenateLimitLines" | "hyphenateLimitZone" | "hyphens" | "imageOrientation" | "imageResolution" | "initialLetter" | "initialLetterAlign" | "initialLetterWrap" | "inlineSize" | "inset" | "insetBlock" | "insetBlockEnd" | "insetBlockStart" | "insetInline" | "insetInlineEnd" | "insetInlineStart" | "isolation" | "justifyContent" | "justifyItems" | "justifySelf" | "letterSpacing" | "lightingColor" | "lineBreak" | "lineGrid" | "lineHeight" | "lineHeightStep" | "lineSnap" | "listStyle" | "listStyleImage" | "listStylePosition" | "listStyleType" | "margin" | "marginBlock" | "marginBlockEnd" | "marginBlockStart" | "marginBottom" | "marginInline" | "marginInlineEnd" | "marginInlineStart" | "marginLeft" | "marginRight" | "marginTop" | "marker" | "markerEnd" | "markerKnockoutLeft" | "markerKnockoutRight" | "markerMid" | "markerPattern" | "markerSegment" | "markerSide" | "markerStart" | "marqueeDirection" | "marqueeLoop" | "marqueeSpeed" | "marqueeStyle" | "mask" | "maskBorder" | "maskBorderMode" | "maskBorderOutset" | "maskBorderRepeat" | "maskBorderSlice" | "maskBorderSource" | "maskBorderWidth" | "maskClip" | "maskComposite" | "maskImage" | "maskMode" | "maskOrigin" | "maskPosition" | "maskRepeat" | "maskSize" | "maskType" | "maxBlockSize" | "maxHeight" | "maxInlineSize" | "maxLines" | "maxWidth" | "minBlockSize" | "minHeight" | "minInlineSize" | "minWidth" | "mixBlendMode" | "navDown" | "navLeft" | "navRight" | "navUp" | "objectFit" | "objectPosition" | "offset" | "offsetAfter" | "offsetAnchor" | "offsetBefore" | "offsetDistance" | "offsetEnd" | "offsetPath" | "offsetPosition" | "offsetRotate" | "offsetStart" | "opacity" | "order" | "orphans" | "outline" | "outlineColor" | "outlineOffset" | "outlineStyle" | "outlineWidth" | "overflow" | "overflowStyle" | "overflowWrap" | "overflowX" | "overflowY" | "padding" | "paddingBlock" | "paddingBlockEnd" | "paddingBlockStart" | "paddingBottom" | "paddingInline" | "paddingInlineEnd" | "paddingInlineStart" | "paddingLeft" | "paddingRight" | "paddingTop" | "page" | "pageBreakAfter" | "pageBreakBefore" | "pageBreakInside" | "pause" | "pauseAfter" | "pauseBefore" | "perspective" | "perspectiveOrigin" | "pitch" | "pitchRange" | "placeContent" | "placeItems" | "placeSelf" | "playDuring" | "pointerEvents" | "position" | "presentationLevel" | "quotes" | "regionFragment" | "resize" | "rest" | "restAfter" | "restBefore" | "richness" | "rotation" | "rotationPoint" | "rowGap" | "rubyAlign" | "rubyMerge" | "rubyPosition" | "running" | "scrollBehavior" | "scrollPadding" | "scrollPaddingBlock" | "scrollPaddingBlockEnd" | "scrollPaddingBlockStart" | "scrollPaddingBottom" | "scrollPaddingInline" | "scrollPaddingInlineEnd" | "scrollPaddingInlineStart" | "scrollPaddingLeft" | "scrollPaddingRight" | "scrollPaddingTop" | "scrollSnapAlign" | "scrollSnapMargin" | "scrollSnapMarginBlock" | "scrollSnapMarginBlockEnd" | "scrollSnapMarginBlockStart" | "scrollSnapMarginBottom" | "scrollSnapMarginInline" | "scrollSnapMarginInlineEnd" | "scrollSnapMarginInlineStart" | "scrollSnapMarginLeft" | "scrollSnapMarginRight" | "scrollSnapMarginTop" | "scrollSnapStop" | "scrollSnapType" | "scrollbarGutter" | "shapeImageThreshold" | "shapeInside" | "shapeMargin" | "shapeOutside" | "speak" | "speakAs" | "speakHeader" | "speakNumeral" | "speakPunctuation" | "speechRate" | "stress" | "stringSet" | "stroke" | "strokeAlign" | "strokeAlignment" | "strokeBreak" | "strokeColor" | "strokeDashCorner" | "strokeDashJustify" | "strokeDashadjust" | "strokeDasharray" | "strokeDashcorner" | "strokeDashoffset" | "strokeImage" | "strokeLinecap" | "strokeLinejoin" | "strokeMiterlimit" | "strokeOpacity" | "strokeOrigin" | "strokePosition" | "strokeRepeat" | "strokeSize" | "strokeWidth" | "tabSize" | "tableLayout" | "textAlign" | "textAlignAll" | "textAlignLast" | "textCombineUpright" | "textDecoration" | "textDecorationColor" | "textDecorationLine" | "textDecorationSkip" | "textDecorationStyle" | "textEmphasis" | "textEmphasisColor" | "textEmphasisPosition" | "textEmphasisStyle" | "textIndent" | "textJustify" | "textOrientation" | "textOverflow" | "textShadow" | "textSpaceCollapse" | "textSpaceTrim" | "textSpacing" | "textTransform" | "textUnderlinePosition" | "textWrap" | "transform" | "transformBox" | "transformOrigin" | "transformStyle" | "transition" | "transitionDelay" | "transitionDuration" | "transitionProperty" | "transitionTimingFunction" | "unicodeBidi" | "userSelect" | "verticalAlign" | "visibility" | "voiceBalance" | "voiceDuration" | "voiceFamily" | "voicePitch" | "voiceRange" | "voiceRate" | "voiceStress" | "voiceVolume" | "volume" | "whiteSpace" | "widows" | "willChange" | "wordBreak" | "wordSpacing" | "wordWrap" | "wrapAfter" | "wrapBefore" | "wrapFlow" | "wrapInside" | "wrapThrough" | "writingMode" | "zIndex" | "palette" | "use" | "fixed" | "opaque" | "absolute" | "relative" | "static" | "sticky" | "tone" | "elementRef">>;
    inputRef: PropTypes.Validator<React.RefObject<any>>;
    isLoading: PropTypes.Requireable<boolean>;
    isRequired: PropTypes.Requireable<boolean>;
    name: PropTypes.Requireable<string>;
    size: PropTypes.Validator<import("../types").Size>;
    mask: PropTypes.Requireable<string>;
    max: PropTypes.Requireable<number>;
    maxLength: PropTypes.Requireable<number>;
    min: PropTypes.Requireable<number>;
    minLength: PropTypes.Requireable<number>;
    multiple: PropTypes.Requireable<boolean>;
    pattern: PropTypes.Requireable<string>;
    placeholder: PropTypes.Requireable<string>;
    readOnly: PropTypes.Requireable<boolean>;
    spellCheck: PropTypes.Requireable<boolean>;
    step: PropTypes.Requireable<number>;
    state: PropTypes.Requireable<string>;
    type: PropTypes.Requireable<string>;
    value: PropTypes.Requireable<string>;
    onBlur: PropTypes.Requireable<(...args: any[]) => any>;
    onChange: PropTypes.Requireable<(...args: any[]) => any>;
    onFocus: PropTypes.Requireable<(...args: any[]) => any>;
    description: PropTypes.Requireable<string | PropTypes.ReactElementLike>;
    hint: PropTypes.Requireable<string | PropTypes.ReactElementLike>;
    isOptional: PropTypes.Requireable<boolean>;
    label: PropTypes.Requireable<string | PropTypes.ReactElementLike>;
    tooltip: PropTypes.Requireable<string | PropTypes.ReactElementLike>;
    tooltipPopoverProps: PropTypes.Requireable<PropTypes.InferProps<any>>;
    tooltipTrigger: PropTypes.Requireable<PropTypes.ReactElementLike>;
    validationText: PropTypes.Requireable<string>;
    addonBefore: PropTypes.Requireable<PropTypes.ReactElementLike>;
    addonAfter: PropTypes.Requireable<PropTypes.ReactElementLike>;
    isVertical: PropTypes.Requireable<boolean>;
};
export declare const inputFieldDefaultProps: {
    after?: React.ReactElement<any, string | ((props: any) => React.ReactElement<any, string | any | (new (props: any) => React.Component<any, any, any>)>) | (new (props: any) => React.Component<any, any, any>)>;
    a11yId: any;
    a11yLabel?: string;
    autoComplete?: string;
    autoFocus?: boolean;
    before?: React.ReactElement<any, string | ((props: any) => React.ReactElement<any, string | any | (new (props: any) => React.Component<any, any, any>)>) | (new (props: any) => React.Component<any, any, any>)>;
    children?: React.ReactNode;
    className: any;
    defaultValue?: string | string[];
    disabled?: boolean;
    inputProps: {};
    inputRef?: React.RefObject<any>;
    isLoading?: boolean;
    isRequired: any;
    name?: string;
    size?: import("../types").Size;
    mask?: string;
    max?: string | number;
    maxLength?: number;
    min?: string | number;
    minLength?: number;
    multiple?: boolean;
    pattern?: string;
    placeholder?: string;
    readOnly?: boolean;
    spellCheck?: boolean;
    step?: string | number;
    state: any;
    type?: string;
    value?: string | number | string[];
    onBlur?: (event: React.FocusEvent<HTMLInputElement>) => void;
    onChange?: (event: React.FormEvent<HTMLInputElement>) => void;
    onFocus?: (event: React.FocusEvent<HTMLInputElement>) => void;
    description: any;
    hint: any;
    isOptional: any;
    label: any;
    tooltip: any;
    tooltipPopoverProps: any;
    tooltipTrigger: any;
    validationText: any;
    addonBefore: any;
    addonAfter: any;
    isVertical: boolean;
};
declare const C: React.FunctionComponent<InputFieldProps> & InputFieldComponents;
export default C;
