import * as React from 'react';
import * as PropTypes from 'prop-types';
import { LocalNavigationProps, NavigationProps } from '../Navigation/Navigation';
import { Omit } from '../types';
import { MenuButtonProps } from './MenuButton';
import { MenuDividerProps } from './MenuDivider';
import { MenuGroupProps } from './MenuGroup';
import { MenuItemProps } from './MenuItem';
import { MenuPopoverProps } from './MenuPopover';
import { MenuTriggerProps } from './MenuTrigger';
import { MenuContextState } from './MenuContext';
export declare type LocalMenuProps = LocalNavigationProps & {
    children: React.ReactNode;
    context?: MenuContextState;
    isHorizontal?: boolean;
    setInitialFocus?: boolean;
};
export declare type MenuProps = Omit<NavigationProps, 'ref'> & LocalMenuProps;
export declare type MenuComponents = {
    Button: React.FunctionComponent<MenuButtonProps>;
    Divider: React.FunctionComponent<MenuDividerProps>;
    Group: React.FunctionComponent<MenuGroupProps>;
    Item: React.FunctionComponent<MenuItemProps>;
    Popover: React.FunctionComponent<MenuPopoverProps>;
    Trigger: React.FunctionComponent<MenuTriggerProps>;
};
declare type State = {
    activeItemIndex: number;
};
export declare const menuPropTypes: {
    children: PropTypes.Validator<PropTypes.ReactNodeLike>;
    isHorizontal: PropTypes.Requireable<boolean>;
    a11yTitle: PropTypes.Requireable<string>;
    className: PropTypes.Requireable<string>;
    role: PropTypes.Requireable<string>;
    use: PropTypes.Requireable<any>;
};
export declare const menuDefaultProps: {
    isHorizontal: boolean;
    role: string;
    setInitialFocus: boolean;
    a11yTitle: any;
    className: any;
    use: any;
};
export declare class Menu extends React.Component<LocalMenuProps, State> {
    static propTypes: {
        children: PropTypes.Validator<PropTypes.ReactNodeLike>;
        isHorizontal: PropTypes.Requireable<boolean>;
        a11yTitle: PropTypes.Requireable<string>;
        className: PropTypes.Requireable<string>;
        role: PropTypes.Requireable<string>;
        use: PropTypes.Requireable<any>;
    };
    static defaultProps: {
        isHorizontal: boolean;
        role: string;
        setInitialFocus: boolean;
        a11yTitle: any;
        className: any;
        use: any;
    };
    menu: React.RefObject<HTMLElement>;
    state: {
        activeItemIndex: number;
    };
    componentDidUpdate: (prevProps: MenuProps) => void;
    handleKeyDown: (e: React.KeyboardEvent<any>) => void;
    handleFocus: () => void;
    render: () => JSX.Element;
}
declare const C: React.FunctionComponent<MenuProps> & MenuComponents;
export default C;
