import * as React from 'react';
import * as PropTypes from 'prop-types';
import { OverlayProps } from '../Overlay/Overlay';
import { ModalContainerProps } from './ModalContainer';
import { ModalHideProps } from './ModalHide';
import { ModalShowProps } from './ModalShow';
import { AnimateProps, RestrictHideProps } from '../types';
export declare type LocalModalProps = {
    children: React.ReactNode | (({ fallbackFocusRef, initialFocusRef }: {
        fallbackFocusRef: React.RefObject<HTMLElement>;
        initialFocusRef: React.RefObject<HTMLElement>;
    }) => React.ReactNode);
    className?: string;
    /** Whether or not to show the modal component */
    isVisible?: boolean;
    hide?(): void;
    kind?: 'alert' | void;
    renderWrapper?(children: React.ReactNode): React.ReactNode;
    showActionButtons?: boolean;
    showCloseButton?: boolean;
} & RestrictHideProps & AnimateProps;
export declare type ModalProps = OverlayProps & LocalModalProps;
export declare type ModalComponents = {
    Container: React.FunctionComponent<ModalContainerProps>;
    Hide: React.FunctionComponent<ModalHideProps>;
    Show: React.FunctionComponent<ModalShowProps>;
};
export declare const Modal: React.FunctionComponent<LocalModalProps> & ModalComponents;
export declare const modalPropTypes: {
    children: PropTypes.Validator<PropTypes.ReactNodeLike>;
    className: PropTypes.Requireable<string>;
    isVisible: PropTypes.Requireable<boolean>;
    hide: PropTypes.Requireable<(...args: any[]) => any>;
    kind: PropTypes.Validator<void | "alert">;
    showActionButtons: PropTypes.Requireable<boolean>;
    showCloseButton: PropTypes.Requireable<boolean>;
    renderWrapper: PropTypes.Requireable<(...args: any[]) => any>;
    hideOnEsc: PropTypes.Requireable<boolean>;
    hideOnClickOutside: PropTypes.Requireable<boolean>;
    delay: PropTypes.Requireable<string>;
    duration: PropTypes.Requireable<string>;
    expand: PropTypes.Validator<boolean | "left" | "right" | "top" | "bottom" | "center">;
    fade: PropTypes.Requireable<boolean>;
    slide: PropTypes.Validator<boolean | "left" | "right" | "top" | "bottom">;
    timing: PropTypes.Requireable<string>;
};
export declare const modalDefaultProps: {
    className: any;
    isVisible: boolean;
    kind: any;
    showActionButtons: boolean;
    showCloseButton: boolean;
    hideOnClickOutside: boolean;
    hideOnEsc: boolean;
    renderWrapper: (children: React.ReactNode) => React.ReactNode;
    delay: any;
    duration: string;
    expand: any;
    fade: boolean;
    slide: boolean;
    timing: any;
};
declare const C: React.FunctionComponent<ModalProps> & ModalComponents;
export default C;
