import * as React from 'react';
import * as PropTypes from 'prop-types';
import { OverlayProps as ReakitOverlayProps } from 'reakit/ts';
import { AnimateProps, Placement, RestrictHideProps } from '../types';
import { OverlayContainerProps } from './OverlayContainer';
import { OverlayHideProps } from './OverlayHide';
export declare type LocalOverlayProps = {
    children: React.ReactNode;
    className?: string;
    /** Whether or not to show the overlay component */
    isVisible?: boolean;
    placement?: Placement;
};
export declare type OverlayProps = LocalOverlayProps & AnimateProps & RestrictHideProps & ReakitOverlayProps;
export declare type OverlayComponents = {
    Container: React.FunctionComponent<OverlayContainerProps>;
    Hide: React.FunctionComponent<OverlayHideProps>;
    Show: any;
    Toggle: any;
};
export declare const Overlay: React.FunctionComponent<LocalOverlayProps & AnimateProps & RestrictHideProps> & OverlayComponents;
export declare const overlayPropTypes: {
    hideOnEsc: PropTypes.Requireable<boolean>;
    hideOnClickOutside: PropTypes.Requireable<boolean>;
    delay: PropTypes.Requireable<string>;
    duration: PropTypes.Requireable<string>;
    expand: PropTypes.Validator<boolean | "left" | "right" | "top" | "bottom" | "center">;
    fade: PropTypes.Requireable<boolean>;
    slide: PropTypes.Validator<boolean | "left" | "right" | "top" | "bottom">;
    timing: PropTypes.Requireable<string>;
    children: PropTypes.Validator<PropTypes.ReactNodeLike>;
    className: PropTypes.Requireable<string>;
    isVisible: PropTypes.Requireable<boolean>;
    placement: PropTypes.Validator<Placement>;
};
export declare const overlayDefaultProps: {
    hideOnEsc: boolean;
    hideOnClickOutside: any;
    delay: any;
    duration: string;
    expand: any;
    fade: boolean;
    slide: boolean;
    timing: any;
    className: any;
    isVisible: boolean;
    placement: any;
};
declare const C: React.FunctionComponent<OverlayProps> & OverlayComponents;
export default C;
