import * as React from 'react';
import * as PropTypes from 'prop-types';
import { LabelProps as ReakitLabelProps } from 'reakit/ts';
export declare type LocalRadioProps = {
    /** An accessible id for the radio */
    a11yId?: string;
    /** Automatically focus on the radio */
    autoFocus?: boolean;
    checked?: boolean;
    className?: string;
    /** Is the radio checked by default */
    defaultChecked?: boolean;
    /** Disables the radio */
    disabled?: boolean;
    /** Makes the radio required and sets aria-invalid to true */
    isRequired?: boolean;
    /** radio label */
    label: string;
    name?: string;
    radioRef?: React.RefObject<any>;
    /** State of the radio. Can be any color in the palette. */
    state?: string;
    /** Controlled value of the radio */
    value?: string;
    /** Function to invoke when focus is lost */
    onBlur?: React.FocusEventHandler<HTMLInputElement>;
    /** Function to invoke when input has changed */
    onChange?: React.FormEventHandler<HTMLInputElement>;
    /** Function to invoke when input is focused */
    onFocus?: React.FocusEventHandler<HTMLInputElement>;
};
export declare type RadioProps = ReakitLabelProps & LocalRadioProps;
export declare type RadioComponents = {
    Formik: React.FunctionComponent<RadioProps>;
    ReduxForm: React.FunctionComponent<RadioProps>;
};
export declare const Radio: React.FunctionComponent<LocalRadioProps> & RadioComponents;
export declare const radioPropTypes: {
    a11yId: PropTypes.Requireable<string>;
    autoFocus: PropTypes.Requireable<boolean>;
    checked: PropTypes.Validator<boolean>;
    className: PropTypes.Requireable<string>;
    defaultChecked: PropTypes.Requireable<boolean>;
    disabled: PropTypes.Requireable<boolean>;
    isRequired: PropTypes.Requireable<boolean>;
    label: PropTypes.Validator<string>;
    onBlur: PropTypes.Requireable<(...args: any[]) => any>;
    onChange: PropTypes.Requireable<(...args: any[]) => any>;
    onFocus: PropTypes.Requireable<(...args: any[]) => any>;
    name: PropTypes.Requireable<string>;
    radioRef: PropTypes.Validator<React.RefObject<any>>;
    state: PropTypes.Requireable<string>;
    value: PropTypes.Requireable<string>;
};
export declare const radioDefaultProps: {
    a11yId: any;
    autoFocus: boolean;
    checked: any;
    className: any;
    defaultChecked: any;
    disabled: boolean;
    isRequired: boolean;
    onBlur: any;
    onChange: any;
    onFocus: any;
    name: any;
    radioRef: any;
    state: any;
    value: any;
};
declare const C: React.FunctionComponent<RadioProps> & RadioComponents;
export default C;
