import * as React from 'react';
import * as PropTypes from 'prop-types';
import { LabelProps as ReakitLabelProps } from 'reakit/ts';
import { Omit } from '../types';
export declare type LocalSwitchProps = {
    /** Automatically focus on the switch */
    autoFocus?: boolean;
    checked?: boolean;
    className?: string;
    /** Is the switch checked by default? */
    defaultChecked?: boolean;
    /** Disables the switch */
    disabled?: boolean;
    /** ID for the switch */
    id?: string;
    /** Makes the switch required and sets aria-invalid to true */
    isRequired?: boolean;
    /** Switch label */
    label?: string;
    name?: string;
    palette?: string;
    /** State of the switch. Can be any color in the palette. */
    state?: string;
    switchRef?: React.RefObject<any>;
    /** Initial value of the switch */
    value?: string;
    /** Function to invoke when focus is lost */
    onBlur?: React.FocusEventHandler<HTMLInputElement>;
    /** Function to invoke when switch has changed */
    onChange?: React.FormEventHandler<HTMLInputElement>;
    /** Function to invoke when switch is focused */
    onFocus?: React.FocusEventHandler<HTMLInputElement>;
};
export declare type SwitchProps = LocalSwitchProps & Omit<ReakitLabelProps, 'children'>;
export declare type SwitchComponents = {
    Formik: React.FunctionComponent<SwitchProps>;
    ReduxForm: React.FunctionComponent<SwitchProps>;
};
export declare const Switch: React.FunctionComponent<LocalSwitchProps> & SwitchComponents;
export declare const switchPropTypes: {
    autoFocus: PropTypes.Requireable<boolean>;
    checked: PropTypes.Requireable<boolean>;
    className: PropTypes.Requireable<string>;
    defaultChecked: PropTypes.Requireable<boolean>;
    disabled: PropTypes.Requireable<boolean>;
    id: PropTypes.Requireable<string>;
    isRequired: PropTypes.Requireable<boolean>;
    label: PropTypes.Requireable<string>;
    name: PropTypes.Requireable<string>;
    palette: PropTypes.Requireable<string>;
    state: PropTypes.Requireable<string>;
    switchRef: PropTypes.Validator<React.RefObject<any>>;
    value: PropTypes.Requireable<string>;
    onBlur: PropTypes.Requireable<(...args: any[]) => any>;
    onChange: PropTypes.Requireable<(...args: any[]) => any>;
    onFocus: PropTypes.Requireable<(...args: any[]) => any>;
};
export declare const switchDefaultProps: {
    autoFocus: boolean;
    checked: any;
    className: any;
    defaultChecked: any;
    disabled: boolean;
    id: any;
    isRequired: boolean;
    label: any;
    onBlur: any;
    onChange: any;
    onFocus: any;
    palette: any;
    name: any;
    state: any;
    switchRef: any;
    value: any;
};
declare const C: React.FunctionComponent<SwitchProps> & SwitchComponents;
export default C;
