import * as React from 'react';
import * as PropTypes from 'prop-types';
import { BoxProps as ReakitBoxProps } from 'reakit/ts/Box/Box';
import { TableBodyProps } from './TableBody';
import { TableCaptionProps } from './TableCaption';
import { TableCellProps } from './TableCell';
import { TableFootProps } from './TableFoot';
import { TableHeadProps } from './TableHead';
import { TableHeadCellProps } from './TableHeadCell';
import { TableRowProps } from './TableRow';
export declare type LocalTableProps = {
    /** Title of the table to be read by screen readers. */
    a11yTitle?: string;
    children: React.ReactNode;
    /** Renders an outer border for the table */
    hasBorder?: boolean;
    isHoverable?: boolean;
    isResponsive?: boolean;
    isStriped?: boolean;
    isVerticallyCentered?: boolean;
    responsiveBreakpoint?: string;
};
export declare type TableProps = ReakitBoxProps & LocalTableProps;
export declare type TableComponents = {
    Body: React.FunctionComponent<TableBodyProps>;
    Caption: React.FunctionComponent<TableCaptionProps>;
    Cell: React.FunctionComponent<TableCellProps>;
    Foot: React.FunctionComponent<TableFootProps>;
    Head: React.FunctionComponent<TableHeadProps>;
    HeadCell: React.FunctionComponent<TableHeadCellProps>;
    Row: React.FunctionComponent<TableRowProps>;
};
export declare const Table: React.FunctionComponent<LocalTableProps> & TableComponents;
export declare const tablePropTypes: {
    a11yTitle: PropTypes.Requireable<string>;
    children: PropTypes.Validator<PropTypes.ReactNodeLike>;
    hasBorder: PropTypes.Requireable<boolean>;
    isHoverable: PropTypes.Requireable<boolean>;
    isResponsive: PropTypes.Requireable<boolean>;
    isStriped: PropTypes.Requireable<boolean>;
    isVerticallyCentered: PropTypes.Requireable<boolean>;
    responsiveBreakpoint: PropTypes.Requireable<string>;
};
export declare const tableDefaultProps: {
    a11yTitle: any;
    hasBorder: boolean;
    isHoverable: boolean;
    isResponsive: boolean;
    isStriped: boolean;
    isVerticallyCentered: boolean;
    responsiveBreakpoint: string;
};
declare const C: React.FunctionComponent<TableProps> & TableComponents;
export default C;
