import * as React from 'react';
import * as PropTypes from 'prop-types';
import { InputProps as ReakitInputProps } from 'reakit/ts/Input/Input';
import { Omit } from '../types';
export declare type LocalTextareaProps = {
    /** An accessible identifier for the textarea */
    a11yId?: string;
    /** An accessible label for the textarea */
    a11yLabel?: string;
    autoComplete?: string;
    /** Automatically focus on the textarea */
    autoFocus?: boolean;
    className?: string;
    /** Default value of the textarea */
    defaultValue?: string;
    /** Disables the textrea */
    disabled?: boolean;
    /** Makes the textarea span full width */
    isFullWidth?: boolean;
    /** Adds a cute loading indicator to the textarea */
    isLoading?: boolean;
    /** Makes the texrea required and sets aria-invalid to true */
    isRequired?: boolean;
    /** Name of the textarea */
    name?: string;
    /** Alters the size of the textarea. Can be "small", "medium" or "large" */
    size?: string;
    /** If the value of the type attribute is text, email, search, password, tel, or url, this attribute specifies the maximum number of characters (in UTF-16 code units) that the user can enter. For other control types, it is ignored. */
    maxLength?: number;
    /** If the value of the type attribute is text, email, search, password, tel, or url, this attribute specifies the minimum number of characters (in UTF-16 code points) that the user can enter. For other control types, it is ignored. */
    minLength?: number;
    /** Regex pattern to apply to the textarea */
    pattern?: string;
    /** Hint text to display */
    placeholder?: string;
    /** This prop prevents the user from modifying the value of the textarea. It is ignored if the value of the type attribute is hidden, range, color, checkbox, radio, file, or a button type (such as button or submit). */
    readOnly?: boolean;
    /** The minimum number of rows in the text area. */
    rows?: number;
    /** Setting the value of this attribute to true indicates that the element needs to have its spelling and grammar checked. The value default indicates that the element is to act according to a default behavior, possibly based on the parent element's own spellcheck value. The value false indicates that the element should not be checked. */
    spellCheck?: boolean;
    /** State of the input. Can be any color in the palette. */
    state?: string;
    textareaRef?: React.RefObject<any>;
    /** Value of the input */
    value?: string;
    /** Function to invoke when focus is lost */
    onBlur?: React.FocusEventHandler<HTMLTextAreaElement>;
    /** Function to invoke when input has changed */
    onChange?: React.FormEventHandler<HTMLTextAreaElement>;
    /** Function to invoke when input is focused */
    onFocus?: React.FocusEventHandler<HTMLTextAreaElement>;
};
export declare type TextareaProps = Omit<ReakitInputProps, 'size'> & LocalTextareaProps;
export declare type TextareaComponents = {
    Formik: React.FunctionComponent<TextareaProps>;
    ReduxForm: React.FunctionComponent<TextareaProps>;
};
export declare const Textarea: React.FunctionComponent<LocalTextareaProps> & TextareaComponents;
export declare const textareaPropTypes: {
    a11yId: PropTypes.Requireable<string>;
    a11yLabel: PropTypes.Requireable<string>;
    autoComplete: PropTypes.Requireable<string>;
    autoFocus: PropTypes.Requireable<boolean>;
    className: PropTypes.Requireable<string>;
    defaultValue: PropTypes.Requireable<string>;
    disabled: PropTypes.Requireable<boolean>;
    isFullWidth: PropTypes.Requireable<boolean>;
    isLoading: PropTypes.Requireable<boolean>;
    isRequired: PropTypes.Requireable<boolean>;
    name: PropTypes.Requireable<string>;
    size: PropTypes.Requireable<string>;
    maxLength: PropTypes.Requireable<number>;
    minLength: PropTypes.Requireable<number>;
    pattern: PropTypes.Requireable<string>;
    placeholder: PropTypes.Requireable<string>;
    readOnly: PropTypes.Requireable<boolean>;
    rows: PropTypes.Requireable<number>;
    spellCheck: PropTypes.Requireable<boolean>;
    state: PropTypes.Requireable<string>;
    textareaRef: PropTypes.Validator<React.RefObject<any>>;
    value: PropTypes.Requireable<string>;
    onBlur: PropTypes.Requireable<(...args: any[]) => any>;
    onChange: PropTypes.Requireable<(...args: any[]) => any>;
    onFocus: PropTypes.Requireable<(...args: any[]) => any>;
};
export declare const textareaDefaultProps: {
    a11yId: any;
    a11yLabel: any;
    autoComplete: any;
    autoFocus: boolean;
    className: any;
    defaultValue: any;
    disabled: boolean;
    isFullWidth: boolean;
    isLoading: boolean;
    isRequired: boolean;
    maxLength: any;
    minLength: any;
    name: any;
    onBlur: any;
    onChange: any;
    onFocus: any;
    pattern: any;
    placeholder: any;
    readOnly: any;
    rows: number;
    spellCheck: any;
    size: string;
    state: any;
    textareaRef: any;
    value: any;
};
export default Textarea;
